/********************************************************************************
** Form generated from reading UI file 'qparametereditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QPARAMETEREDITOR_H
#define UI_QPARAMETEREDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"

QT_BEGIN_NAMESPACE

class Ui_QParameterEditor
{
public:
    QGridLayout *gridLayout;
    EquationEdit *value;
    QLabel *valueInvalidLabel;
    QListWidget *list;
    QPushButton *cmdNew;
    QPushButton *cmdDelete;
    QSpacerItem *spacerItem;
    QPushButton *moveUp;
    QPushButton *moveDown;
    QSpacerItem *spacerItem1;
    QPushButton *cmdImport;
    QPushButton *cmdExport;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *QParameterEditor)
    {
        if (QParameterEditor->objectName().isEmpty())
            QParameterEditor->setObjectName("QParameterEditor");
        QParameterEditor->resize(381, 488);
        gridLayout = new QGridLayout(QParameterEditor);
        gridLayout->setObjectName("gridLayout");
        value = new EquationEdit(QParameterEditor);
        value->setObjectName("value");

        gridLayout->addWidget(value, 0, 0, 1, 1);

        valueInvalidLabel = new QLabel(QParameterEditor);
        valueInvalidLabel->setObjectName("valueInvalidLabel");

        gridLayout->addWidget(valueInvalidLabel, 0, 1, 1, 1);

        list = new QListWidget(QParameterEditor);
        list->setObjectName("list");
        list->setSelectionBehavior(QAbstractItemView::SelectRows);

        gridLayout->addWidget(list, 1, 0, 9, 1);

        cmdNew = new QPushButton(QParameterEditor);
        cmdNew->setObjectName("cmdNew");

        gridLayout->addWidget(cmdNew, 1, 1, 1, 1);

        cmdDelete = new QPushButton(QParameterEditor);
        cmdDelete->setObjectName("cmdDelete");
        cmdDelete->setEnabled(false);

        gridLayout->addWidget(cmdDelete, 2, 1, 1, 1);

        spacerItem = new QSpacerItem(51, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);

        moveUp = new QPushButton(QParameterEditor);
        moveUp->setObjectName("moveUp");

        gridLayout->addWidget(moveUp, 4, 1, 1, 1);

        moveDown = new QPushButton(QParameterEditor);
        moveDown->setObjectName("moveDown");

        gridLayout->addWidget(moveDown, 5, 1, 1, 1);

        spacerItem1 = new QSpacerItem(51, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(spacerItem1, 6, 1, 1, 1);

        cmdImport = new QPushButton(QParameterEditor);
        cmdImport->setObjectName("cmdImport");
        cmdImport->setEnabled(true);

        gridLayout->addWidget(cmdImport, 7, 1, 1, 1);

        cmdExport = new QPushButton(QParameterEditor);
        cmdExport->setObjectName("cmdExport");
        cmdExport->setEnabled(true);

        gridLayout->addWidget(cmdExport, 8, 1, 1, 1);

        spacerItem2 = new QSpacerItem(102, 121, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem2, 9, 1, 1, 1);


        retranslateUi(QParameterEditor);

        QMetaObject::connectSlotsByName(QParameterEditor);
    } // setupUi

    void retranslateUi(QWidget *QParameterEditor)
    {
        QParameterEditor->setWindowTitle(tr2i18n("Parameter Editor", nullptr));
#if QT_CONFIG(tooltip)
        valueInvalidLabel->setToolTip(tr2i18n("The value must be a number (e.g. \"pi^2\")", nullptr));
#endif // QT_CONFIG(tooltip)
        valueInvalidLabel->setText(tr2i18n("(invalid)", nullptr));
#if QT_CONFIG(tooltip)
        cmdNew->setToolTip(tr2i18n("Add a new constant", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmdNew->setWhatsThis(tr2i18n("Click this button to add a new constant.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cmdNew->setText(tr2i18n("&New", nullptr));
#if QT_CONFIG(tooltip)
        cmdDelete->setToolTip(tr2i18n("delete selected constant", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmdDelete->setWhatsThis(tr2i18n("Click here to delete the selected constant; it can only be removed if it is not currently used by a plot.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cmdDelete->setText(tr2i18n("&Delete", nullptr));
        moveUp->setText(tr2i18n("Move Up", nullptr));
        moveDown->setText(tr2i18n("Move Down", nullptr));
#if QT_CONFIG(tooltip)
        cmdImport->setToolTip(tr2i18n("Import values from a textfile", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmdImport->setWhatsThis(tr2i18n("Import values from a textfile. Every line in the file is parsed as a value or expression.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cmdImport->setText(tr2i18n("&Import...", nullptr));
#if QT_CONFIG(tooltip)
        cmdExport->setToolTip(tr2i18n("Export values to a textfile", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmdExport->setWhatsThis(tr2i18n("Export values to a textfile. Every value in the parameter list will be written to one line in the file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cmdExport->setText(tr2i18n("&Export...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QParameterEditor: public Ui_QParameterEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QPARAMETEREDITOR_H

