/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmplot.Parser.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "parseradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ParserAdaptor
 */

ParserAdaptor::ParserAdaptor(XParser *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ParserAdaptor::~ParserAdaptor()
{
    // destructor
}

int ParserAdaptor::addFunction(const QString &f_str0, const QString &f_str1)
{
    // handle method call org.kde.kmplot.Parser.addFunction
    return parent()->addFunction(f_str0, f_str1);
}

uint ParserAdaptor::countFunctions()
{
    // handle method call org.kde.kmplot.Parser.countFunctions
    return parent()->countFunctions();
}

double ParserAdaptor::fkt(uint id, uint eq, double eq_)
{
    // handle method call org.kde.kmplot.Parser.fkt
    return parent()->fkt(id, eq, eq_);
}

int ParserAdaptor::fnameToID(const QString &name)
{
    // handle method call org.kde.kmplot.Parser.fnameToID
    return parent()->fnameToID(name);
}

bool ParserAdaptor::functionAddParameter(uint id, const QString &new_parameter)
{
    // handle method call org.kde.kmplot.Parser.functionAddParameter
    return parent()->functionAddParameter(id, new_parameter);
}

double ParserAdaptor::functionF1LineWidth(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionF1LineWidth
    return parent()->functionF1LineWidth(id);
}

bool ParserAdaptor::functionF1Visible(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionF1Visible
    return parent()->functionF1Visible(id);
}

double ParserAdaptor::functionF2LineWidth(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionF2LineWidth
    return parent()->functionF2LineWidth(id);
}

bool ParserAdaptor::functionF2Visible(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionF2Visible
    return parent()->functionF2Visible(id);
}

double ParserAdaptor::functionFLineWidth(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionFLineWidth
    return parent()->functionFLineWidth(id);
}

bool ParserAdaptor::functionFVisible(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionFVisible
    return parent()->functionFVisible(id);
}

double ParserAdaptor::functionIntLineWidth(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionIntLineWidth
    return parent()->functionIntLineWidth(id);
}

bool ParserAdaptor::functionIntVisible(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionIntVisible
    return parent()->functionIntVisible(id);
}

QString ParserAdaptor::functionMaxValue(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionMaxValue
    return parent()->functionMaxValue(id);
}

QString ParserAdaptor::functionMinValue(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionMinValue
    return parent()->functionMinValue(id);
}

QStringList ParserAdaptor::functionParameterList(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionParameterList
    return parent()->functionParameterList(id);
}

bool ParserAdaptor::functionRemoveParameter(uint id, const QString &remove_parameter)
{
    // handle method call org.kde.kmplot.Parser.functionRemoveParameter
    return parent()->functionRemoveParameter(id, remove_parameter);
}

QString ParserAdaptor::functionStartXValue(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionStartXValue
    return parent()->functionStartXValue(id);
}

QString ParserAdaptor::functionStartYValue(uint id)
{
    // handle method call org.kde.kmplot.Parser.functionStartYValue
    return parent()->functionStartYValue(id);
}

QString ParserAdaptor::functionStr(uint id, uint eq)
{
    // handle method call org.kde.kmplot.Parser.functionStr
    return parent()->functionStr(id, eq);
}

QStringList ParserAdaptor::listFunctionNames()
{
    // handle method call org.kde.kmplot.Parser.listFunctionNames
    return parent()->listFunctionNames();
}

bool ParserAdaptor::removeFunction(uint id)
{
    // handle method call org.kde.kmplot.Parser.removeFunction
    return parent()->removeFunction(id);
}

bool ParserAdaptor::setFunctionExpression(uint id, uint eq, const QString &f_str)
{
    // handle method call org.kde.kmplot.Parser.setFunctionExpression
    return parent()->setFunctionExpression(id, eq, f_str);
}

bool ParserAdaptor::setFunctionF1LineWidth(uint id, double linewidth)
{
    // handle method call org.kde.kmplot.Parser.setFunctionF1LineWidth
    return parent()->setFunctionF1LineWidth(id, linewidth);
}

void ParserAdaptor::setFunctionF1Visible(uint id, bool visible)
{
    // handle method call org.kde.kmplot.Parser.setFunctionF1Visible
    parent()->setFunctionF1Visible(id, visible);
}

bool ParserAdaptor::setFunctionF2LineWidth(uint id, double linewidth)
{
    // handle method call org.kde.kmplot.Parser.setFunctionF2LineWidth
    return parent()->setFunctionF2LineWidth(id, linewidth);
}

void ParserAdaptor::setFunctionF2Visible(uint id, bool visible)
{
    // handle method call org.kde.kmplot.Parser.setFunctionF2Visible
    parent()->setFunctionF2Visible(id, visible);
}

bool ParserAdaptor::setFunctionFLineWidth(uint id, double linewidth)
{
    // handle method call org.kde.kmplot.Parser.setFunctionFLineWidth
    return parent()->setFunctionFLineWidth(id, linewidth);
}

void ParserAdaptor::setFunctionFVisible(uint id, bool visible)
{
    // handle method call org.kde.kmplot.Parser.setFunctionFVisible
    parent()->setFunctionFVisible(id, visible);
}

bool ParserAdaptor::setFunctionIntLineWidth(uint id, double linewidth)
{
    // handle method call org.kde.kmplot.Parser.setFunctionIntLineWidth
    return parent()->setFunctionIntLineWidth(id, linewidth);
}

void ParserAdaptor::setFunctionIntVisible(uint id, bool visible)
{
    // handle method call org.kde.kmplot.Parser.setFunctionIntVisible
    parent()->setFunctionIntVisible(id, visible);
}

bool ParserAdaptor::setFunctionMaxValue(uint id, const QString &max)
{
    // handle method call org.kde.kmplot.Parser.setFunctionMaxValue
    return parent()->setFunctionMaxValue(id, max);
}

bool ParserAdaptor::setFunctionMinValue(uint id, const QString &min)
{
    // handle method call org.kde.kmplot.Parser.setFunctionMinValue
    return parent()->setFunctionMinValue(id, min);
}

bool ParserAdaptor::setFunctionStartValue(uint id, const QString &x, const QString &y)
{
    // handle method call org.kde.kmplot.Parser.setFunctionStartValue
    return parent()->setFunctionStartValue(id, x, y);
}


#include "moc_parseradaptor.cpp"
