/****************************************************************************
** Meta object code from reading C++ file 'maindlgadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "maindlgadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maindlgadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14MainDlgAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MainDlgAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14MainDlgAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainDlgAdaptor",
        "D-Bus Interface",
        "org.kde.kmplot.MainDlg",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kmplot.MainDlg\">\n    <method name=\""
        "editAxes\"/>\n    <method name=\"toggleShowSliders\"/>\n    <metho"
        "d name=\"slotSave\"/>\n    <method name=\"slotSaveas\"/>\n    <met"
        "hod name=\"slotPrint\"/>\n    <method name=\"slotExport\"/>\n    <"
        "method name=\"slotSettings\"/>\n    <method name=\"slotNames\"/>\n"
        "    <method name=\"slotResetView\"/>\n    <method name=\"calculato"
        "r\"/>\n    <method name=\"findMinimumValue\"/>\n    <method name=\""
        "findMaximumValue\"/>\n    <method name=\"graphArea\"/>\n    <metho"
        "d name=\"checkModified\">\n      <arg direction=\"out\" type=\"b\""
        "/>\n    </method>\n    <method name=\"isModified\">\n      <arg di"
        "rection=\"out\" type=\"b\"/>\n    </method>\n  </interface>\n",
        "calculator",
        "",
        "checkModified",
        "editAxes",
        "findMaximumValue",
        "findMinimumValue",
        "graphArea",
        "isModified",
        "slotExport",
        "slotNames",
        "slotPrint",
        "slotResetView",
        "slotSave",
        "slotSaveas",
        "slotSettings",
        "toggleShowSliders"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'calculator'
        QtMocHelpers::SlotData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkModified'
        QtMocHelpers::SlotData<bool()>(7, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'editAxes'
        QtMocHelpers::SlotData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findMaximumValue'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findMinimumValue'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'graphArea'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'isModified'
        QtMocHelpers::SlotData<bool()>(12, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotExport'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNames'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrint'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotResetView'
        QtMocHelpers::SlotData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSave'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveas'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSettings'
        QtMocHelpers::SlotData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleShowSliders'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MainDlgAdaptor, qt_meta_tag_ZN14MainDlgAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MainDlgAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MainDlgAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MainDlgAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MainDlgAdaptorE_t>.metaTypes,
    nullptr
} };

void MainDlgAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainDlgAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->calculator(); break;
        case 1: { bool _r = _t->checkModified();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->editAxes(); break;
        case 3: _t->findMaximumValue(); break;
        case 4: _t->findMinimumValue(); break;
        case 5: _t->graphArea(); break;
        case 6: { bool _r = _t->isModified();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->slotExport(); break;
        case 8: _t->slotNames(); break;
        case 9: _t->slotPrint(); break;
        case 10: _t->slotResetView(); break;
        case 11: _t->slotSave(); break;
        case 12: _t->slotSaveas(); break;
        case 13: _t->slotSettings(); break;
        case 14: _t->toggleShowSliders(); break;
        default: ;
        }
    }
}

const QMetaObject *MainDlgAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainDlgAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MainDlgAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MainDlgAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
