/********************************************************************************
** Form generated from reading UI file 'initialconditionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INITIALCONDITIONSWIDGET_H
#define UI_INITIALCONDITIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "initialconditionseditor.h"

QT_BEGIN_NAMESPACE

class Ui_InitialConditionsWidget
{
public:
    QVBoxLayout *vboxLayout;
    InitialConditionsView *view;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *removeButton;
    QPushButton *addButton;

    void setupUi(QWidget *InitialConditionsWidget)
    {
        if (InitialConditionsWidget->objectName().isEmpty())
            InitialConditionsWidget->setObjectName("InitialConditionsWidget");
        InitialConditionsWidget->resize(400, 398);
        vboxLayout = new QVBoxLayout(InitialConditionsWidget);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        view = new InitialConditionsView(InitialConditionsWidget);
        view->setObjectName("view");

        vboxLayout->addWidget(view);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        removeButton = new QPushButton(InitialConditionsWidget);
        removeButton->setObjectName("removeButton");

        hboxLayout->addWidget(removeButton);

        addButton = new QPushButton(InitialConditionsWidget);
        addButton->setObjectName("addButton");

        hboxLayout->addWidget(addButton);


        vboxLayout->addLayout(hboxLayout);

        QWidget::setTabOrder(removeButton, addButton);

        retranslateUi(InitialConditionsWidget);

        QMetaObject::connectSlotsByName(InitialConditionsWidget);
    } // setupUi

    void retranslateUi(QWidget *InitialConditionsWidget)
    {
        InitialConditionsWidget->setWindowTitle(tr2i18n("Initial Conditions", nullptr));
        removeButton->setText(tr2i18n("Remove", nullptr));
        addButton->setText(tr2i18n("Add...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InitialConditionsWidget: public Ui_InitialConditionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INITIALCONDITIONSWIDGET_H

