/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmplot.MainDlg.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef MAINDLGADAPTOR_H
#define MAINDLGADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "maindlg.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kmplot.MainDlg
 */
class MainDlgAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kmplot.MainDlg")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kmplot.MainDlg\">\n"
"    <method name=\"editAxes\"/>\n"
"    <method name=\"toggleShowSliders\"/>\n"
"    <method name=\"slotSave\"/>\n"
"    <method name=\"slotSaveas\"/>\n"
"    <method name=\"slotPrint\"/>\n"
"    <method name=\"slotExport\"/>\n"
"    <method name=\"slotSettings\"/>\n"
"    <method name=\"slotNames\"/>\n"
"    <method name=\"slotResetView\"/>\n"
"    <method name=\"calculator\"/>\n"
"    <method name=\"findMinimumValue\"/>\n"
"    <method name=\"findMaximumValue\"/>\n"
"    <method name=\"graphArea\"/>\n"
"    <method name=\"checkModified\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isModified\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    MainDlgAdaptor(MainDlg *parent);
    ~MainDlgAdaptor() override;

    inline MainDlg *parent() const
    { return static_cast<MainDlg *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void calculator();
    bool checkModified();
    void editAxes();
    void findMaximumValue();
    void findMinimumValue();
    void graphArea();
    bool isModified();
    void slotExport();
    void slotNames();
    void slotPrint();
    void slotResetView();
    void slotSave();
    void slotSaveas();
    void slotSettings();
    void toggleShowSliders();
Q_SIGNALS: // SIGNALS
};

#endif
