/********************************************************************************
** Form generated from reading UI file 'settingspagediagram.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSPAGEDIAGRAM_H
#define UI_SETTINGSPAGEDIAGRAM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsPageDiagram
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *kcfg_GridStyle;
    QVBoxLayout *vboxLayout;
    QRadioButton *radioButton11;
    QRadioButton *radioButton12;
    QRadioButton *radioButton13;
    QRadioButton *radioButton14;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QLineEdit *kcfg_LabelHorizontalAxis;
    QLabel *label_2;
    QLineEdit *kcfg_LabelVerticalAxis;
    QLabel *textLabel7;
    QDoubleSpinBox *kcfg_AxesLineWidth;
    QLabel *textLabel5;
    QDoubleSpinBox *kcfg_GridLineWidth;
    QLabel *textLabel9;
    QDoubleSpinBox *kcfg_TicWidth;
    QLabel *textLabel8_4;
    QDoubleSpinBox *kcfg_TicLength;
    QCheckBox *kcfg_ShowLabel;
    QCheckBox *kcfg_ShowAxes;
    QCheckBox *kcfg_ShowArrows;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SettingsPageDiagram)
    {
        if (SettingsPageDiagram->objectName().isEmpty())
            SettingsPageDiagram->setObjectName("SettingsPageDiagram");
        SettingsPageDiagram->resize(307, 459);
        gridLayout_2 = new QGridLayout(SettingsPageDiagram);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_GridStyle = new QGroupBox(SettingsPageDiagram);
        kcfg_GridStyle->setObjectName("kcfg_GridStyle");
        vboxLayout = new QVBoxLayout(kcfg_GridStyle);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        radioButton11 = new QRadioButton(kcfg_GridStyle);
        radioButton11->setObjectName("radioButton11");

        vboxLayout->addWidget(radioButton11);

        radioButton12 = new QRadioButton(kcfg_GridStyle);
        radioButton12->setObjectName("radioButton12");

        vboxLayout->addWidget(radioButton12);

        radioButton13 = new QRadioButton(kcfg_GridStyle);
        radioButton13->setObjectName("radioButton13");

        vboxLayout->addWidget(radioButton13);

        radioButton14 = new QRadioButton(kcfg_GridStyle);
        radioButton14->setObjectName("radioButton14");

        vboxLayout->addWidget(radioButton14);


        gridLayout_2->addWidget(kcfg_GridStyle, 0, 0, 1, 2);

        groupBox = new QGroupBox(SettingsPageDiagram);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_LabelHorizontalAxis = new QLineEdit(groupBox);
        kcfg_LabelHorizontalAxis->setObjectName("kcfg_LabelHorizontalAxis");

        gridLayout->addWidget(kcfg_LabelHorizontalAxis, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        kcfg_LabelVerticalAxis = new QLineEdit(groupBox);
        kcfg_LabelVerticalAxis->setObjectName("kcfg_LabelVerticalAxis");

        gridLayout->addWidget(kcfg_LabelVerticalAxis, 1, 1, 1, 1);


        gridLayout_2->addWidget(groupBox, 1, 0, 1, 2);

        textLabel7 = new QLabel(SettingsPageDiagram);
        textLabel7->setObjectName("textLabel7");
        textLabel7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(textLabel7, 2, 0, 1, 1);

        kcfg_AxesLineWidth = new QDoubleSpinBox(SettingsPageDiagram);
        kcfg_AxesLineWidth->setObjectName("kcfg_AxesLineWidth");
        kcfg_AxesLineWidth->setAlignment(Qt::AlignRight);
        kcfg_AxesLineWidth->setDecimals(1);
        kcfg_AxesLineWidth->setMinimum(0.100000000000000);
        kcfg_AxesLineWidth->setSingleStep(0.100000000000000);

        gridLayout_2->addWidget(kcfg_AxesLineWidth, 2, 1, 1, 1);

        textLabel5 = new QLabel(SettingsPageDiagram);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(textLabel5, 3, 0, 1, 1);

        kcfg_GridLineWidth = new QDoubleSpinBox(SettingsPageDiagram);
        kcfg_GridLineWidth->setObjectName("kcfg_GridLineWidth");
        kcfg_GridLineWidth->setAlignment(Qt::AlignRight);
        kcfg_GridLineWidth->setDecimals(1);
        kcfg_GridLineWidth->setMinimum(0.100000000000000);
        kcfg_GridLineWidth->setSingleStep(0.100000000000000);

        gridLayout_2->addWidget(kcfg_GridLineWidth, 3, 1, 1, 1);

        textLabel9 = new QLabel(SettingsPageDiagram);
        textLabel9->setObjectName("textLabel9");
        textLabel9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(textLabel9, 4, 0, 1, 1);

        kcfg_TicWidth = new QDoubleSpinBox(SettingsPageDiagram);
        kcfg_TicWidth->setObjectName("kcfg_TicWidth");
        kcfg_TicWidth->setAlignment(Qt::AlignRight);
        kcfg_TicWidth->setDecimals(1);
        kcfg_TicWidth->setMinimum(0.100000000000000);
        kcfg_TicWidth->setSingleStep(0.100000000000000);

        gridLayout_2->addWidget(kcfg_TicWidth, 4, 1, 1, 1);

        textLabel8_4 = new QLabel(SettingsPageDiagram);
        textLabel8_4->setObjectName("textLabel8_4");
        textLabel8_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(textLabel8_4, 5, 0, 1, 1);

        kcfg_TicLength = new QDoubleSpinBox(SettingsPageDiagram);
        kcfg_TicLength->setObjectName("kcfg_TicLength");
        kcfg_TicLength->setAlignment(Qt::AlignRight);
        kcfg_TicLength->setDecimals(1);
        kcfg_TicLength->setMinimum(0.100000000000000);
        kcfg_TicLength->setSingleStep(0.100000000000000);

        gridLayout_2->addWidget(kcfg_TicLength, 5, 1, 1, 1);

        kcfg_ShowLabel = new QCheckBox(SettingsPageDiagram);
        kcfg_ShowLabel->setObjectName("kcfg_ShowLabel");
        kcfg_ShowLabel->setChecked(true);

        gridLayout_2->addWidget(kcfg_ShowLabel, 6, 0, 1, 1);

        kcfg_ShowAxes = new QCheckBox(SettingsPageDiagram);
        kcfg_ShowAxes->setObjectName("kcfg_ShowAxes");
        kcfg_ShowAxes->setChecked(true);

        gridLayout_2->addWidget(kcfg_ShowAxes, 7, 0, 1, 1);

        kcfg_ShowArrows = new QCheckBox(SettingsPageDiagram);
        kcfg_ShowArrows->setObjectName("kcfg_ShowArrows");
        kcfg_ShowArrows->setChecked(true);

        gridLayout_2->addWidget(kcfg_ShowArrows, 8, 0, 1, 1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(spacerItem, 9, 0, 1, 1);

#if QT_CONFIG(shortcut)
        textLabel7->setBuddy(kcfg_AxesLineWidth);
        textLabel5->setBuddy(kcfg_GridLineWidth);
        textLabel9->setBuddy(kcfg_TicWidth);
        textLabel8_4->setBuddy(kcfg_TicLength);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SettingsPageDiagram);

        QMetaObject::connectSlotsByName(SettingsPageDiagram);
    } // setupUi

    void retranslateUi(QWidget *SettingsPageDiagram)
    {
        SettingsPageDiagram->setWindowTitle(tr2i18n("Diagram", nullptr));
        kcfg_GridStyle->setTitle(tr2i18n("Grid Style", nullptr));
#if QT_CONFIG(whatsthis)
        radioButton11->setWhatsThis(tr2i18n("No Grid will be plotted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioButton11->setText(tr2i18n("None", nullptr));
#if QT_CONFIG(whatsthis)
        radioButton12->setWhatsThis(tr2i18n("A line for every tic.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioButton12->setText(tr2i18n("Lines", nullptr));
#if QT_CONFIG(whatsthis)
        radioButton13->setWhatsThis(tr2i18n("Only little crosses in the plot area.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioButton13->setText(tr2i18n("Crosses", nullptr));
#if QT_CONFIG(whatsthis)
        radioButton14->setWhatsThis(tr2i18n("Circles around the Origin.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioButton14->setText(tr2i18n("Polar", nullptr));
        groupBox->setTitle(tr2i18n("Axis Labels", nullptr));
#if QT_CONFIG(whatsthis)
        label->setWhatsThis(tr2i18n("Label on horizontal axis.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Horizontal axis label:", nullptr));
        kcfg_LabelHorizontalAxis->setText(tr2i18n("X", nullptr));
#if QT_CONFIG(whatsthis)
        label_2->setWhatsThis(tr2i18n("Label on vertical axis.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Vertical axis label:", nullptr));
        kcfg_LabelVerticalAxis->setText(tr2i18n("Y", nullptr));
        textLabel7->setText(tr2i18n("Axis widths:", nullptr));
        kcfg_AxesLineWidth->setSuffix(tr2i18n(" mm", nullptr));
        textLabel5->setText(tr2i18n("Line &width:", nullptr));
        kcfg_GridLineWidth->setSuffix(tr2i18n(" mm", nullptr));
        textLabel9->setText(tr2i18n("Tic width:", nullptr));
        kcfg_TicWidth->setSuffix(tr2i18n(" mm", nullptr));
        textLabel8_4->setText(tr2i18n("Tic length:", nullptr));
        kcfg_TicLength->setSuffix(tr2i18n(" mm", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowLabel->setToolTip(tr2i18n("Visible tic labels.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowLabel->setWhatsThis(tr2i18n("Check this if the axes' tics should be labeled.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowLabel->setText(tr2i18n("Show labels", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowAxes->setToolTip(tr2i18n("Visible axes.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowAxes->setWhatsThis(tr2i18n("Check this if the axes should be visible.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowAxes->setText(tr2i18n("Show axes", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowArrows->setToolTip(tr2i18n("Visible arrows at the end of the axes.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_ShowArrows->setWhatsThis(tr2i18n("Check this if the axes should have arrows at their ends.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_ShowArrows->setText(tr2i18n("Show arrows", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsPageDiagram: public Ui_SettingsPageDiagram {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSPAGEDIAGRAM_H

