/********************************************************************************
** Form generated from reading UI file 'parameterswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARAMETERSWIDGET_H
#define UI_PARAMETERSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ParametersWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *useSlider;
    QCheckBox *useList;
    QPushButton *editParameterListButton;
    QComboBox *listOfSliders;

    void setupUi(QWidget *ParametersWidget)
    {
        if (ParametersWidget->objectName().isEmpty())
            ParametersWidget->setObjectName("ParametersWidget");
        ParametersWidget->resize(555, 185);
        gridLayout = new QGridLayout(ParametersWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(6);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(9, 9, 9, 9);
        useSlider = new QCheckBox(ParametersWidget);
        useSlider->setObjectName("useSlider");

        gridLayout->addWidget(useSlider, 1, 0, 1, 1);

        useList = new QCheckBox(ParametersWidget);
        useList->setObjectName("useList");

        gridLayout->addWidget(useList, 0, 0, 1, 1);

        editParameterListButton = new QPushButton(ParametersWidget);
        editParameterListButton->setObjectName("editParameterListButton");
        editParameterListButton->setEnabled(false);

        gridLayout->addWidget(editParameterListButton, 0, 1, 1, 1);

        listOfSliders = new QComboBox(ParametersWidget);
        listOfSliders->setObjectName("listOfSliders");
        listOfSliders->setEnabled(false);

        gridLayout->addWidget(listOfSliders, 1, 1, 1, 1);

        QWidget::setTabOrder(useList, editParameterListButton);
        QWidget::setTabOrder(editParameterListButton, useSlider);
        QWidget::setTabOrder(useSlider, listOfSliders);

        retranslateUi(ParametersWidget);
        QObject::connect(useList, &QCheckBox::toggled, editParameterListButton, &QPushButton::setEnabled);
        QObject::connect(useSlider, &QCheckBox::toggled, listOfSliders, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(ParametersWidget);
    } // setupUi

    void retranslateUi(QWidget *ParametersWidget)
    {
        ParametersWidget->setWindowTitle(tr2i18n("Parameters", nullptr));
        useSlider->setText(tr2i18n("Slider:", nullptr));
        useList->setText(tr2i18n("List:", nullptr));
#if QT_CONFIG(tooltip)
        editParameterListButton->setToolTip(tr2i18n("Edit the list of parameters", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        editParameterListButton->setWhatsThis(tr2i18n("Click here to open a list of parameter values. Here you can add, remove, and change them.", nullptr));
#endif // QT_CONFIG(whatsthis)
        editParameterListButton->setText(tr2i18n("Edit List...", nullptr));
#if QT_CONFIG(tooltip)
        listOfSliders->setToolTip(tr2i18n("Select a slider", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        listOfSliders->setWhatsThis(tr2i18n("Select one of the sliders to change the parameter value dynamically. The values vary from 0 (left) to 100 (right).", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class ParametersWidget: public Ui_ParametersWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARAMETERSWIDGET_H

