/********************************************************************************
** Form generated from reading UI file 'sliderwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SLIDERWIDGET_H
#define UI_SLIDERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"

QT_BEGIN_NAMESPACE

class Ui_SliderWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QSlider *slider;
    QLabel *valueLabel;
    QHBoxLayout *hboxLayout1;
    QLabel *label;
    EquationEdit *min;
    QSpacerItem *spacerItem;
    QLabel *label_2;
    EquationEdit *max;

    void setupUi(QWidget *SliderWidget)
    {
        if (SliderWidget->objectName().isEmpty())
            SliderWidget->setObjectName("SliderWidget");
        SliderWidget->resize(748, 116);
        vboxLayout = new QVBoxLayout(SliderWidget);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        slider = new QSlider(SliderWidget);
        slider->setObjectName("slider");
        slider->setMaximum(1000);
        slider->setSingleStep(10);
        slider->setPageStep(100);
        slider->setOrientation(Qt::Horizontal);

        hboxLayout->addWidget(slider);

        valueLabel = new QLabel(SliderWidget);
        valueLabel->setObjectName("valueLabel");
        valueLabel->setMinimumSize(QSize(50, 0));
        valueLabel->setAlignment(Qt::AlignCenter);

        hboxLayout->addWidget(valueLabel);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label = new QLabel(SliderWidget);
        label->setObjectName("label");

        hboxLayout1->addWidget(label);

        min = new EquationEdit(SliderWidget);
        min->setObjectName("min");

        hboxLayout1->addWidget(min);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        label_2 = new QLabel(SliderWidget);
        label_2->setObjectName("label_2");

        hboxLayout1->addWidget(label_2);

        max = new EquationEdit(SliderWidget);
        max->setObjectName("max");

        hboxLayout1->addWidget(max);


        vboxLayout->addLayout(hboxLayout1);


        retranslateUi(SliderWidget);

        QMetaObject::connectSlotsByName(SliderWidget);
    } // setupUi

    void retranslateUi(QWidget *SliderWidget)
    {
        SliderWidget->setWindowTitle(tr2i18n("Slider", nullptr));
        valueLabel->setText(tr2i18n("<0>", nullptr));
        label->setText(tr2i18n("Min:", nullptr));
        label_2->setText(tr2i18n("Max:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SliderWidget: public Ui_SliderWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SLIDERWIDGET_H

