/****************************************************************************
** Meta object code from reading C++ file 'parseradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "parseradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'parseradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ParserAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ParserAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13ParserAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ParserAdaptor",
        "D-Bus Interface",
        "org.kde.kmplot.Parser",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kmplot.Parser\">\n    <method name=\"a"
        "ddFunction\">\n      <arg direction=\"in\" type=\"s\" name=\"f_str"
        "0\"/>\n      <arg direction=\"in\" type=\"s\" name=\"f_str1\"/>\n "
        "     <arg direction=\"out\" type=\"i\"/>\n    </method>\n    <meth"
        "od name=\"removeFunction\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"id\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </m"
        "ethod>\n    <method name=\"setFunctionExpression\">\n      <arg di"
        "rection=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"in"
        "\" type=\"u\" name=\"eq\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"f_str\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    "
        "</method>\n    <method name=\"countFunctions\">\n      <arg direct"
        "ion=\"out\" type=\"u\"/>\n    </method>\n    <method name=\"listFu"
        "nctionNames\">\n      <arg direction=\"out\" type=\"as\"/>\n    </"
        "method>\n    <method name=\"fnameToID\">\n      <arg direction=\"o"
        "ut\" type=\"i\"/>\n      <arg direction=\"in\" type=\"s\" name=\"n"
        "ame\"/>\n    </method>\n    <method name=\"fkt\">\n      <arg dire"
        "ction=\"out\" type=\"d\"/>\n      <arg direction=\"in\" type=\"u\""
        " name=\"id\"/>\n      <arg direction=\"in\" type=\"u\" name=\"eq\""
        "/>\n      <arg direction=\"in\" type=\"d\" name=\"eq\"/>\n    </me"
        "thod>\n    <method name=\"functionFVisible\">\n      <arg directio"
        "n=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"out\" ty"
        "pe=\"b\"/>\n    </method>\n    <method name=\"functionF1Visible\">"
        "\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n      <arg"
        " direction=\"out\" type=\"b\"/>\n    </method>\n    <method name=\""
        "functionF2Visible\">\n      <arg direction=\"in\" type=\"u\" name="
        "\"id\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </method>"
        "\n    <method name=\"functionIntVisible\">\n      <arg direction=\""
        "in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"setFunctionFVisible\">\n "
        "     <arg direction=\"in\" type=\"u\" name=\"id\"/>\n      <arg di"
        "rection=\"in\" type=\"b\" name=\"visible\"/>\n    </method>\n    <"
        "method name=\"setFunctionF1Visible\">\n      <arg direction=\"in\""
        " type=\"u\" name=\"id\"/>\n      <arg direction=\"in\" type=\"b\" "
        "name=\"visible\"/>\n    </method>\n    <method name=\"setFunctionF"
        "2Visible\">\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n"
        "      <arg direction=\"in\" type=\"b\" name=\"visible\"/>\n    </m"
        "ethod>\n    <method name=\"setFunctionIntVisible\">\n      <arg di"
        "rection=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"in"
        "\" type=\"b\" name=\"visible\"/>\n    </method>\n    <method name="
        "\"functionStr\">\n      <arg direction=\"in\" type=\"u\" name=\"id"
        "\"/>\n      <arg direction=\"in\" type=\"u\" name=\"eq\"/>\n      "
        "<arg direction=\"out\" type=\"s\"/>\n    </method>\n    <method na"
        "me=\"functionFLineWidth\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"id\"/>\n      <arg direction=\"out\" type=\"d\"/>\n    </m"
        "ethod>\n    <method name=\"functionF1LineWidth\">\n      <arg dire"
        "ction=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"out\""
        " type=\"d\"/>\n    </method>\n    <method name=\"functionF2LineWid"
        "th\">\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n     "
        " <arg direction=\"out\" type=\"d\"/>\n    </method>\n    <method n"
        "ame=\"functionIntLineWidth\">\n      <arg direction=\"in\" type=\""
        "u\" name=\"id\"/>\n      <arg direction=\"out\" type=\"d\"/>\n    "
        "</method>\n    <method name=\"setFunctionFLineWidth\">\n      <arg"
        " direction=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\""
        "in\" type=\"d\" name=\"linewidth\"/>\n      <arg direction=\"out\""
        " type=\"b\"/>\n    </method>\n    <method name=\"setFunctionF1Line"
        "Width\">\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n  "
        "    <arg direction=\"in\" type=\"d\" name=\"linewidth\"/>\n      <"
        "arg direction=\"out\" type=\"b\"/>\n    </method>\n    <method nam"
        "e=\"setFunctionF2LineWidth\">\n      <arg direction=\"in\" type=\""
        "u\" name=\"id\"/>\n      <arg direction=\"in\" type=\"d\" name=\"l"
        "inewidth\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    </met"
        "hod>\n    <method name=\"setFunctionIntLineWidth\">\n      <arg di"
        "rection=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"in"
        "\" type=\"d\" name=\"linewidth\"/>\n      <arg direction=\"out\" t"
        "ype=\"b\"/>\n    </method>\n    <method name=\"functionParameterLi"
        "st\">\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n     "
        " <arg direction=\"out\" type=\"as\"/>\n    </method>\n    <method "
        "name=\"functionAddParameter\">\n      <arg direction=\"in\" type=\""
        "u\" name=\"id\"/>\n      <arg direction=\"in\" type=\"s\" name=\"n"
        "ew_parameter\"/>\n      <arg direction=\"out\" type=\"b\"/>\n    <"
        "/method>\n    <method name=\"functionRemoveParameter\">\n      <ar"
        "g direction=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction="
        "\"in\" type=\"s\" name=\"remove_parameter\"/>\n      <arg directio"
        "n=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"function"
        "MinValue\">\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n"
        "      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <met"
        "hod name=\"functionMaxValue\">\n      <arg direction=\"in\" type=\""
        "u\" name=\"id\"/>\n      <arg direction=\"out\" type=\"s\"/>\n    "
        "</method>\n    <method name=\"setFunctionMaxValue\">\n      <arg d"
        "irection=\"in\" type=\"u\" name=\"id\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"max\"/>\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"setFunctionMinValue\">\n "
        "     <arg direction=\"in\" type=\"u\" name=\"id\"/>\n      <arg di"
        "rection=\"in\" type=\"s\" name=\"min\"/>\n      <arg direction=\"o"
        "ut\" type=\"b\"/>\n    </method>\n    <method name=\"functionStart"
        "XValue\">\n      <arg direction=\"in\" type=\"u\" name=\"id\"/>\n "
        "     <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <meth"
        "od name=\"functionStartYValue\">\n      <arg direction=\"in\" type"
        "=\"u\" name=\"id\"/>\n      <arg direction=\"out\" type=\"s\"/>\n "
        "   </method>\n    <method name=\"setFunctionStartValue\">\n      <"
        "arg direction=\"in\" type=\"u\" name=\"id\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"x\"/>\n      <arg direction=\"in\" type"
        "=\"s\" name=\"y\"/>\n      <arg direction=\"out\" type=\"b\"/>\n  "
        "  </method>\n  </interface>\n",
        "addFunction",
        "",
        "f_str0",
        "f_str1",
        "countFunctions",
        "fkt",
        "id",
        "eq",
        "eq_",
        "fnameToID",
        "name",
        "functionAddParameter",
        "new_parameter",
        "functionF1LineWidth",
        "functionF1Visible",
        "functionF2LineWidth",
        "functionF2Visible",
        "functionFLineWidth",
        "functionFVisible",
        "functionIntLineWidth",
        "functionIntVisible",
        "functionMaxValue",
        "functionMinValue",
        "functionParameterList",
        "functionRemoveParameter",
        "remove_parameter",
        "functionStartXValue",
        "functionStartYValue",
        "functionStr",
        "listFunctionNames",
        "removeFunction",
        "setFunctionExpression",
        "f_str",
        "setFunctionF1LineWidth",
        "linewidth",
        "setFunctionF1Visible",
        "visible",
        "setFunctionF2LineWidth",
        "setFunctionF2Visible",
        "setFunctionFLineWidth",
        "setFunctionFVisible",
        "setFunctionIntLineWidth",
        "setFunctionIntVisible",
        "setFunctionMaxValue",
        "max",
        "setFunctionMinValue",
        "min",
        "setFunctionStartValue",
        "x",
        "y"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addFunction'
        QtMocHelpers::SlotData<int(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'countFunctions'
        QtMocHelpers::SlotData<uint()>(9, 6, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'fkt'
        QtMocHelpers::SlotData<double(uint, uint, double)>(10, 6, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::UInt, 11 }, { QMetaType::UInt, 12 }, { QMetaType::Double, 13 },
        }}),
        // Slot 'fnameToID'
        QtMocHelpers::SlotData<int(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'functionAddParameter'
        QtMocHelpers::SlotData<bool(uint, const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'functionF1LineWidth'
        QtMocHelpers::SlotData<double(uint)>(18, 6, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionF1Visible'
        QtMocHelpers::SlotData<bool(uint)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionF2LineWidth'
        QtMocHelpers::SlotData<double(uint)>(20, 6, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionF2Visible'
        QtMocHelpers::SlotData<bool(uint)>(21, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionFLineWidth'
        QtMocHelpers::SlotData<double(uint)>(22, 6, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionFVisible'
        QtMocHelpers::SlotData<bool(uint)>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionIntLineWidth'
        QtMocHelpers::SlotData<double(uint)>(24, 6, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionIntVisible'
        QtMocHelpers::SlotData<bool(uint)>(25, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionMaxValue'
        QtMocHelpers::SlotData<QString(uint)>(26, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionMinValue'
        QtMocHelpers::SlotData<QString(uint)>(27, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionParameterList'
        QtMocHelpers::SlotData<QStringList(uint)>(28, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionRemoveParameter'
        QtMocHelpers::SlotData<bool(uint, const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'functionStartXValue'
        QtMocHelpers::SlotData<QString(uint)>(31, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionStartYValue'
        QtMocHelpers::SlotData<QString(uint)>(32, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'functionStr'
        QtMocHelpers::SlotData<QString(uint, uint)>(33, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 11 }, { QMetaType::UInt, 12 },
        }}),
        // Slot 'listFunctionNames'
        QtMocHelpers::SlotData<QStringList()>(34, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'removeFunction'
        QtMocHelpers::SlotData<bool(uint)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 },
        }}),
        // Slot 'setFunctionExpression'
        QtMocHelpers::SlotData<bool(uint, uint, const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::UInt, 12 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'setFunctionF1LineWidth'
        QtMocHelpers::SlotData<bool(uint, double)>(38, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::Double, 39 },
        }}),
        // Slot 'setFunctionF1Visible'
        QtMocHelpers::SlotData<void(uint, bool)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'setFunctionF2LineWidth'
        QtMocHelpers::SlotData<bool(uint, double)>(42, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::Double, 39 },
        }}),
        // Slot 'setFunctionF2Visible'
        QtMocHelpers::SlotData<void(uint, bool)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'setFunctionFLineWidth'
        QtMocHelpers::SlotData<bool(uint, double)>(44, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::Double, 39 },
        }}),
        // Slot 'setFunctionFVisible'
        QtMocHelpers::SlotData<void(uint, bool)>(45, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'setFunctionIntLineWidth'
        QtMocHelpers::SlotData<bool(uint, double)>(46, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::Double, 39 },
        }}),
        // Slot 'setFunctionIntVisible'
        QtMocHelpers::SlotData<void(uint, bool)>(47, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 11 }, { QMetaType::Bool, 41 },
        }}),
        // Slot 'setFunctionMaxValue'
        QtMocHelpers::SlotData<bool(uint, const QString &)>(48, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::QString, 49 },
        }}),
        // Slot 'setFunctionMinValue'
        QtMocHelpers::SlotData<bool(uint, const QString &)>(50, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::QString, 51 },
        }}),
        // Slot 'setFunctionStartValue'
        QtMocHelpers::SlotData<bool(uint, const QString &, const QString &)>(52, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 11 }, { QMetaType::QString, 53 }, { QMetaType::QString, 54 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ParserAdaptor, qt_meta_tag_ZN13ParserAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ParserAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ParserAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ParserAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ParserAdaptorE_t>.metaTypes,
    nullptr
} };

void ParserAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ParserAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { int _r = _t->addFunction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 1: { uint _r = _t->countFunctions();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 2: { double _r = _t->fkt((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->fnameToID((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->functionAddParameter((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { double _r = _t->functionF1LineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->functionF1Visible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { double _r = _t->functionF2LineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->functionF2Visible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { double _r = _t->functionFLineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->functionFVisible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { double _r = _t->functionIntLineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->functionIntVisible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->functionMaxValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->functionMinValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QStringList _r = _t->functionParameterList((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->functionRemoveParameter((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->functionStartXValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->functionStartYValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->functionStr((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QStringList _r = _t->listFunctionNames();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->removeFunction((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->setFunctionExpression((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->setFunctionF1LineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->setFunctionF1Visible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: { bool _r = _t->setFunctionF2LineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setFunctionF2Visible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 27: { bool _r = _t->setFunctionFLineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->setFunctionFVisible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 29: { bool _r = _t->setFunctionIntLineWidth((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setFunctionIntVisible((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: { bool _r = _t->setFunctionMaxValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->setFunctionMinValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->setFunctionStartValue((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ParserAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ParserAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ParserAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ParserAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    return _id;
}
QT_WARNING_POP
