/********************************************************************************
** Form generated from reading UI file 'functioneditorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FUNCTIONEDITORWIDGET_H
#define UI_FUNCTIONEDITORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"
#include "functioneditor.h"
#include "initialconditionseditor.h"
#include "klineedit.h"
#include "parameterswidget.h"
#include "plotstylewidget.h"

QT_BEGIN_NAMESPACE

class Ui_FunctionEditorWidget
{
public:
    QVBoxLayout *vboxLayout;
    FunctionListWidget *functionList;
    QGridLayout *gridLayout;
    QPushButton *deleteButton;
    QSpacerItem *spacerItem;
    QPushButton *createNewPlot;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QVBoxLayout *vboxLayout1;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *vboxLayout2;
    EquationEdit *cartesianEquation;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QCheckBox *cartesianCustomMax;
    QCheckBox *cartesianCustomMin;
    EquationEdit *cartesianMin;
    EquationEdit *cartesianMax;
    ParametersWidget *cartesianParameters;
    PlotStyleWidget *cartesian_f0;
    QWidget *tab_3;
    QVBoxLayout *vboxLayout3;
    QCheckBox *showDerivative1;
    PlotStyleWidget *cartesian_f1;
    QCheckBox *showDerivative2;
    PlotStyleWidget *cartesian_f2;
    QWidget *tab_2;
    QGridLayout *gridLayout3;
    QCheckBox *showIntegral;
    QGroupBox *groupBox_6;
    QGridLayout *gridLayout2;
    QLabel *textLabel1_5;
    QLabel *textLabel1_5_2;
    EquationEdit *txtInitX;
    EquationEdit *txtInitY;
    QGroupBox *groupBox_8;
    QHBoxLayout *hboxLayout;
    QLabel *label_6;
    EquationEdit *integralStep;
    PlotStyleWidget *cartesian_integral;
    QSpacerItem *spacerItem1;
    QWidget *page_3;
    QVBoxLayout *vboxLayout4;
    QGroupBox *groupBox_11;
    QGridLayout *gridLayout4;
    QLabel *textLabelX;
    EquationEdit *parametricX;
    QLabel *textLabelY;
    EquationEdit *parametricY;
    QGroupBox *groupBox_9;
    QGridLayout *gridLayout5;
    QLabel *label;
    QLabel *label_2;
    EquationEdit *parametricMin;
    EquationEdit *parametricMax;
    ParametersWidget *parametricParameters;
    PlotStyleWidget *parametric_f0;
    QWidget *page_4;
    QVBoxLayout *vboxLayout5;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout6;
    EquationEdit *polarEquation;
    QGroupBox *groupBox_13;
    QGridLayout *gridLayout6;
    EquationEdit *polarMin;
    EquationEdit *polarMax;
    QLabel *label_3;
    QLabel *label_4;
    ParametersWidget *polarParameters;
    PlotStyleWidget *polar_f0;
    QWidget *page_5;
    QVBoxLayout *vboxLayout7;
    QGroupBox *groupBox_12;
    QGridLayout *gridLayout7;
    KLineEdit *implicitName;
    QLabel *textLabel4_2;
    EquationEdit *implicitEquation;
    ParametersWidget *implicitParameters;
    PlotStyleWidget *implicit_f0;
    QWidget *page_6;
    QVBoxLayout *vboxLayout8;
    QTabWidget *differentialTabWidget;
    QWidget *tab_4;
    QGridLayout *gridLayout_2;
    EquationEdit *differentialEquation;
    QGroupBox *groupBox_10;
    QHBoxLayout *hboxLayout1;
    QLabel *label_7;
    EquationEdit *differentialStep;
    ParametersWidget *differentialParameters;
    PlotStyleWidget *differential_f0;
    QWidget *tab_5;
    QVBoxLayout *vboxLayout9;
    InitialConditionsEditor *initialConditions;
    QWidget *page_2;

    void setupUi(QWidget *FunctionEditorWidget)
    {
        if (FunctionEditorWidget->objectName().isEmpty())
            FunctionEditorWidget->setObjectName("FunctionEditorWidget");
        FunctionEditorWidget->resize(348, 673);
        vboxLayout = new QVBoxLayout(FunctionEditorWidget);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        functionList = new FunctionListWidget(FunctionEditorWidget);
        functionList->setObjectName("functionList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(functionList->sizePolicy().hasHeightForWidth());
        functionList->setSizePolicy(sizePolicy);
        functionList->setMaximumSize(QSize(16777215, 300));

        vboxLayout->addWidget(functionList);

        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        deleteButton = new QPushButton(FunctionEditorWidget);
        deleteButton->setObjectName("deleteButton");
        deleteButton->setEnabled(false);

        gridLayout->addWidget(deleteButton, 0, 2, 1, 1);

        spacerItem = new QSpacerItem(140, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 1, 1, 1);

        createNewPlot = new QPushButton(FunctionEditorWidget);
        createNewPlot->setObjectName("createNewPlot");

        gridLayout->addWidget(createNewPlot, 0, 0, 1, 1);


        vboxLayout->addLayout(gridLayout);

        stackedWidget = new QStackedWidget(FunctionEditorWidget);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        vboxLayout1 = new QVBoxLayout(page);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        tabWidget = new QTabWidget(page);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        vboxLayout2 = new QVBoxLayout(tab);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout2->setObjectName("vboxLayout2");
        cartesianEquation = new EquationEdit(tab);
        cartesianEquation->setObjectName("cartesianEquation");

        vboxLayout2->addWidget(cartesianEquation);

        groupBox = new QGroupBox(tab);
        groupBox->setObjectName("groupBox");
        gridLayout1 = new QGridLayout(groupBox);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout1->setObjectName("gridLayout1");
        cartesianCustomMax = new QCheckBox(groupBox);
        cartesianCustomMax->setObjectName("cartesianCustomMax");

        gridLayout1->addWidget(cartesianCustomMax, 1, 0, 1, 1);

        cartesianCustomMin = new QCheckBox(groupBox);
        cartesianCustomMin->setObjectName("cartesianCustomMin");

        gridLayout1->addWidget(cartesianCustomMin, 0, 0, 1, 1);

        cartesianMin = new EquationEdit(groupBox);
        cartesianMin->setObjectName("cartesianMin");
        cartesianMin->setEnabled(false);

        gridLayout1->addWidget(cartesianMin, 0, 1, 1, 1);

        cartesianMax = new EquationEdit(groupBox);
        cartesianMax->setObjectName("cartesianMax");
        cartesianMax->setEnabled(false);

        gridLayout1->addWidget(cartesianMax, 1, 1, 1, 1);


        vboxLayout2->addWidget(groupBox);

        cartesianParameters = new ParametersWidget(tab);
        cartesianParameters->setObjectName("cartesianParameters");

        vboxLayout2->addWidget(cartesianParameters);

        cartesian_f0 = new PlotStyleWidget(tab);
        cartesian_f0->setObjectName("cartesian_f0");

        vboxLayout2->addWidget(cartesian_f0);

        tabWidget->addTab(tab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        vboxLayout3 = new QVBoxLayout(tab_3);
#ifndef UI_Q_OS_MAC
        vboxLayout3->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout3->setObjectName("vboxLayout3");
        showDerivative1 = new QCheckBox(tab_3);
        showDerivative1->setObjectName("showDerivative1");

        vboxLayout3->addWidget(showDerivative1);

        cartesian_f1 = new PlotStyleWidget(tab_3);
        cartesian_f1->setObjectName("cartesian_f1");
        cartesian_f1->setEnabled(false);

        vboxLayout3->addWidget(cartesian_f1);

        showDerivative2 = new QCheckBox(tab_3);
        showDerivative2->setObjectName("showDerivative2");

        vboxLayout3->addWidget(showDerivative2);

        cartesian_f2 = new PlotStyleWidget(tab_3);
        cartesian_f2->setObjectName("cartesian_f2");
        cartesian_f2->setEnabled(false);

        vboxLayout3->addWidget(cartesian_f2);

        tabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout3 = new QGridLayout(tab_2);
#ifndef UI_Q_OS_MAC
        gridLayout3->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout3->setObjectName("gridLayout3");
        showIntegral = new QCheckBox(tab_2);
        showIntegral->setObjectName("showIntegral");

        gridLayout3->addWidget(showIntegral, 0, 0, 1, 1);

        groupBox_6 = new QGroupBox(tab_2);
        groupBox_6->setObjectName("groupBox_6");
        groupBox_6->setEnabled(false);
        gridLayout2 = new QGridLayout(groupBox_6);
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout2->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout2->setObjectName("gridLayout2");
        textLabel1_5 = new QLabel(groupBox_6);
        textLabel1_5->setObjectName("textLabel1_5");

        gridLayout2->addWidget(textLabel1_5, 0, 0, 1, 1);

        textLabel1_5_2 = new QLabel(groupBox_6);
        textLabel1_5_2->setObjectName("textLabel1_5_2");

        gridLayout2->addWidget(textLabel1_5_2, 1, 0, 1, 1);

        txtInitX = new EquationEdit(groupBox_6);
        txtInitX->setObjectName("txtInitX");

        gridLayout2->addWidget(txtInitX, 0, 1, 1, 1);

        txtInitY = new EquationEdit(groupBox_6);
        txtInitY->setObjectName("txtInitY");

        gridLayout2->addWidget(txtInitY, 1, 1, 1, 1);


        gridLayout3->addWidget(groupBox_6, 1, 0, 1, 1);

        groupBox_8 = new QGroupBox(tab_2);
        groupBox_8->setObjectName("groupBox_8");
        groupBox_8->setEnabled(false);
        hboxLayout = new QHBoxLayout(groupBox_8);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        hboxLayout->setObjectName("hboxLayout");
        label_6 = new QLabel(groupBox_8);
        label_6->setObjectName("label_6");

        hboxLayout->addWidget(label_6);

        integralStep = new EquationEdit(groupBox_8);
        integralStep->setObjectName("integralStep");

        hboxLayout->addWidget(integralStep);


        gridLayout3->addWidget(groupBox_8, 2, 0, 1, 1);

        cartesian_integral = new PlotStyleWidget(tab_2);
        cartesian_integral->setObjectName("cartesian_integral");
        cartesian_integral->setEnabled(false);

        gridLayout3->addWidget(cartesian_integral, 3, 0, 1, 1);

        spacerItem1 = new QSpacerItem(10, 79, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout3->addItem(spacerItem1, 4, 0, 1, 1);

        tabWidget->addTab(tab_2, QString());

        vboxLayout1->addWidget(tabWidget);

        stackedWidget->addWidget(page);
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        vboxLayout4 = new QVBoxLayout(page_3);
#ifndef UI_Q_OS_MAC
        vboxLayout4->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout4->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout4->setObjectName("vboxLayout4");
        groupBox_11 = new QGroupBox(page_3);
        groupBox_11->setObjectName("groupBox_11");
        gridLayout4 = new QGridLayout(groupBox_11);
#ifndef UI_Q_OS_MAC
        gridLayout4->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout4->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout4->setObjectName("gridLayout4");
        textLabelX = new QLabel(groupBox_11);
        textLabelX->setObjectName("textLabelX");
        textLabelX->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout4->addWidget(textLabelX, 0, 0, 1, 1);

        parametricX = new EquationEdit(groupBox_11);
        parametricX->setObjectName("parametricX");

        gridLayout4->addWidget(parametricX, 0, 1, 1, 1);

        textLabelY = new QLabel(groupBox_11);
        textLabelY->setObjectName("textLabelY");
        textLabelY->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout4->addWidget(textLabelY, 1, 0, 1, 1);

        parametricY = new EquationEdit(groupBox_11);
        parametricY->setObjectName("parametricY");

        gridLayout4->addWidget(parametricY, 1, 1, 1, 1);


        vboxLayout4->addWidget(groupBox_11);

        groupBox_9 = new QGroupBox(page_3);
        groupBox_9->setObjectName("groupBox_9");
        gridLayout5 = new QGridLayout(groupBox_9);
#ifndef UI_Q_OS_MAC
        gridLayout5->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout5->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout5->setObjectName("gridLayout5");
        label = new QLabel(groupBox_9);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout5->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(groupBox_9);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout5->addWidget(label_2, 1, 0, 1, 1);

        parametricMin = new EquationEdit(groupBox_9);
        parametricMin->setObjectName("parametricMin");
        parametricMin->setEnabled(true);

        gridLayout5->addWidget(parametricMin, 0, 1, 1, 1);

        parametricMax = new EquationEdit(groupBox_9);
        parametricMax->setObjectName("parametricMax");
        parametricMax->setEnabled(true);

        gridLayout5->addWidget(parametricMax, 1, 1, 1, 1);


        vboxLayout4->addWidget(groupBox_9);

        parametricParameters = new ParametersWidget(page_3);
        parametricParameters->setObjectName("parametricParameters");

        vboxLayout4->addWidget(parametricParameters);

        parametric_f0 = new PlotStyleWidget(page_3);
        parametric_f0->setObjectName("parametric_f0");

        vboxLayout4->addWidget(parametric_f0);

        stackedWidget->addWidget(page_3);
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        vboxLayout5 = new QVBoxLayout(page_4);
#ifndef UI_Q_OS_MAC
        vboxLayout5->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout5->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout5->setObjectName("vboxLayout5");
        groupBox_2 = new QGroupBox(page_4);
        groupBox_2->setObjectName("groupBox_2");
        vboxLayout6 = new QVBoxLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        vboxLayout6->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout6->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout6->setObjectName("vboxLayout6");
        polarEquation = new EquationEdit(groupBox_2);
        polarEquation->setObjectName("polarEquation");

        vboxLayout6->addWidget(polarEquation);


        vboxLayout5->addWidget(groupBox_2);

        groupBox_13 = new QGroupBox(page_4);
        groupBox_13->setObjectName("groupBox_13");
        gridLayout6 = new QGridLayout(groupBox_13);
#ifndef UI_Q_OS_MAC
        gridLayout6->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout6->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout6->setObjectName("gridLayout6");
        polarMin = new EquationEdit(groupBox_13);
        polarMin->setObjectName("polarMin");

        gridLayout6->addWidget(polarMin, 0, 1, 1, 1);

        polarMax = new EquationEdit(groupBox_13);
        polarMax->setObjectName("polarMax");

        gridLayout6->addWidget(polarMax, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox_13);
        label_3->setObjectName("label_3");

        gridLayout6->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(groupBox_13);
        label_4->setObjectName("label_4");

        gridLayout6->addWidget(label_4, 1, 0, 1, 1);


        vboxLayout5->addWidget(groupBox_13);

        polarParameters = new ParametersWidget(page_4);
        polarParameters->setObjectName("polarParameters");

        vboxLayout5->addWidget(polarParameters);

        polar_f0 = new PlotStyleWidget(page_4);
        polar_f0->setObjectName("polar_f0");

        vboxLayout5->addWidget(polar_f0);

        stackedWidget->addWidget(page_4);
        page_5 = new QWidget();
        page_5->setObjectName("page_5");
        vboxLayout7 = new QVBoxLayout(page_5);
#ifndef UI_Q_OS_MAC
        vboxLayout7->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout7->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout7->setObjectName("vboxLayout7");
        groupBox_12 = new QGroupBox(page_5);
        groupBox_12->setObjectName("groupBox_12");
        gridLayout7 = new QGridLayout(groupBox_12);
#ifndef UI_Q_OS_MAC
        gridLayout7->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout7->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout7->setObjectName("gridLayout7");
        implicitName = new KLineEdit(groupBox_12);
        implicitName->setObjectName("implicitName");

        gridLayout7->addWidget(implicitName, 0, 1, 1, 1);

        textLabel4_2 = new QLabel(groupBox_12);
        textLabel4_2->setObjectName("textLabel4_2");

        gridLayout7->addWidget(textLabel4_2, 0, 0, 1, 1);

        implicitEquation = new EquationEdit(groupBox_12);
        implicitEquation->setObjectName("implicitEquation");

        gridLayout7->addWidget(implicitEquation, 1, 0, 1, 2);


        vboxLayout7->addWidget(groupBox_12);

        implicitParameters = new ParametersWidget(page_5);
        implicitParameters->setObjectName("implicitParameters");

        vboxLayout7->addWidget(implicitParameters);

        implicit_f0 = new PlotStyleWidget(page_5);
        implicit_f0->setObjectName("implicit_f0");

        vboxLayout7->addWidget(implicit_f0);

        stackedWidget->addWidget(page_5);
        page_6 = new QWidget();
        page_6->setObjectName("page_6");
        vboxLayout8 = new QVBoxLayout(page_6);
#ifndef UI_Q_OS_MAC
        vboxLayout8->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout8->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout8->setObjectName("vboxLayout8");
        differentialTabWidget = new QTabWidget(page_6);
        differentialTabWidget->setObjectName("differentialTabWidget");
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_2 = new QGridLayout(tab_4);
#ifndef UI_Q_OS_MAC
        gridLayout_2->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout_2->setObjectName("gridLayout_2");
        differentialEquation = new EquationEdit(tab_4);
        differentialEquation->setObjectName("differentialEquation");

        gridLayout_2->addWidget(differentialEquation, 0, 0, 1, 1);

        groupBox_10 = new QGroupBox(tab_4);
        groupBox_10->setObjectName("groupBox_10");
        hboxLayout1 = new QHBoxLayout(groupBox_10);
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        hboxLayout1->setObjectName("hboxLayout1");
        label_7 = new QLabel(groupBox_10);
        label_7->setObjectName("label_7");

        hboxLayout1->addWidget(label_7);

        differentialStep = new EquationEdit(groupBox_10);
        differentialStep->setObjectName("differentialStep");

        hboxLayout1->addWidget(differentialStep);


        gridLayout_2->addWidget(groupBox_10, 1, 0, 1, 1);

        differentialParameters = new ParametersWidget(tab_4);
        differentialParameters->setObjectName("differentialParameters");

        gridLayout_2->addWidget(differentialParameters, 2, 0, 1, 1);

        differential_f0 = new PlotStyleWidget(tab_4);
        differential_f0->setObjectName("differential_f0");

        gridLayout_2->addWidget(differential_f0, 3, 0, 1, 1);

        differentialTabWidget->addTab(tab_4, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        vboxLayout9 = new QVBoxLayout(tab_5);
#ifndef UI_Q_OS_MAC
        vboxLayout9->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout9->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout9->setObjectName("vboxLayout9");
        initialConditions = new InitialConditionsEditor(tab_5);
        initialConditions->setObjectName("initialConditions");

        vboxLayout9->addWidget(initialConditions);

        differentialTabWidget->addTab(tab_5, QString());

        vboxLayout8->addWidget(differentialTabWidget);

        stackedWidget->addWidget(page_6);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        stackedWidget->addWidget(page_2);

        vboxLayout->addWidget(stackedWidget);

        vboxLayout->setStretch(0, 5000);
        vboxLayout->setStretch(1, 1);
        vboxLayout->setStretch(2, 100);
#if QT_CONFIG(shortcut)
        textLabel1_5->setBuddy(txtInitX);
        textLabel1_5_2->setBuddy(txtInitY);
        label_6->setBuddy(integralStep);
        label_3->setBuddy(polarMin);
        label_4->setBuddy(polarMax);
        textLabel4_2->setBuddy(implicitName);
        label_7->setBuddy(integralStep);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(functionList, createNewPlot);
        QWidget::setTabOrder(createNewPlot, deleteButton);
        QWidget::setTabOrder(deleteButton, tabWidget);
        QWidget::setTabOrder(tabWidget, cartesianEquation);
        QWidget::setTabOrder(cartesianEquation, cartesianCustomMin);
        QWidget::setTabOrder(cartesianCustomMin, cartesianMin);
        QWidget::setTabOrder(cartesianMin, cartesianCustomMax);
        QWidget::setTabOrder(cartesianCustomMax, cartesianMax);
        QWidget::setTabOrder(cartesianMax, showDerivative1);
        QWidget::setTabOrder(showDerivative1, showDerivative2);
        QWidget::setTabOrder(showDerivative2, showIntegral);
        QWidget::setTabOrder(showIntegral, txtInitX);
        QWidget::setTabOrder(txtInitX, txtInitY);
        QWidget::setTabOrder(txtInitY, integralStep);
        QWidget::setTabOrder(integralStep, parametricX);
        QWidget::setTabOrder(parametricX, parametricY);
        QWidget::setTabOrder(parametricY, parametricMin);
        QWidget::setTabOrder(parametricMin, parametricMax);
        QWidget::setTabOrder(parametricMax, polarEquation);
        QWidget::setTabOrder(polarEquation, polarMin);
        QWidget::setTabOrder(polarMin, polarMax);
        QWidget::setTabOrder(polarMax, implicitName);
        QWidget::setTabOrder(implicitName, implicitEquation);
        QWidget::setTabOrder(implicitEquation, differentialTabWidget);
        QWidget::setTabOrder(differentialTabWidget, differentialEquation);
        QWidget::setTabOrder(differentialEquation, differentialStep);

        retranslateUi(FunctionEditorWidget);
        QObject::connect(showDerivative1, SIGNAL(toggled(bool)), cartesian_f1, SLOT(setEnabled(bool)));
        QObject::connect(showDerivative2, SIGNAL(toggled(bool)), cartesian_f2, SLOT(setEnabled(bool)));
        QObject::connect(showIntegral, &QCheckBox::toggled, groupBox_8, &QGroupBox::setEnabled);
        QObject::connect(showIntegral, &QCheckBox::toggled, groupBox_6, &QGroupBox::setEnabled);
        QObject::connect(showIntegral, SIGNAL(toggled(bool)), cartesian_integral, SLOT(setEnabled(bool)));
        QObject::connect(cartesianCustomMin, SIGNAL(toggled(bool)), cartesianMin, SLOT(setEnabled(bool)));
        QObject::connect(cartesianCustomMax, SIGNAL(toggled(bool)), cartesianMax, SLOT(setEnabled(bool)));

        stackedWidget->setCurrentIndex(1);
        tabWidget->setCurrentIndex(0);
        differentialTabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(FunctionEditorWidget);
    } // setupUi

    void retranslateUi(QWidget *FunctionEditorWidget)
    {
#if QT_CONFIG(tooltip)
        deleteButton->setToolTip(tr2i18n("delete the selected function", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        deleteButton->setWhatsThis(tr2i18n("Click here to delete the selected function from the list.", nullptr));
#endif // QT_CONFIG(whatsthis)
        deleteButton->setText(tr2i18n("&Delete", nullptr));
        createNewPlot->setText(tr2i18n("Create", nullptr));
        groupBox->setTitle(tr2i18n("Custom plot range", nullptr));
#if QT_CONFIG(tooltip)
        cartesianCustomMax->setToolTip(tr2i18n("Customize the maximum plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cartesianCustomMax->setWhatsThis(tr2i18n("Check this button and enter the plot range boundaries below.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cartesianCustomMax->setText(tr2i18n("Max:", nullptr));
#if QT_CONFIG(tooltip)
        cartesianCustomMin->setToolTip(tr2i18n("Customize the minimum plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cartesianCustomMin->setWhatsThis(tr2i18n("Check this button and enter the plot range boundaries below.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cartesianCustomMin->setText(tr2i18n("Min:", nullptr));
#if QT_CONFIG(tooltip)
        cartesianMin->setToolTip(tr2i18n("lower boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cartesianMin->setWhatsThis(tr2i18n("Enter the lower boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        cartesianMax->setToolTip(tr2i18n("upper boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cartesianMax->setWhatsThis(tr2i18n("Enter the upper boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cartesianParameters->setTitle(tr2i18n("Parameters", nullptr));
        cartesian_f0->setTitle(tr2i18n("Appearance", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Function", nullptr));
#if QT_CONFIG(tooltip)
        showDerivative1->setToolTip(tr2i18n("Show first derivative", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        showDerivative1->setWhatsThis(tr2i18n("If this box is checked, the first derivative will be plotted, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        showDerivative1->setText(tr2i18n("Show &1st derivative", nullptr));
        cartesian_f1->setTitle(tr2i18n("1st derivative", nullptr));
#if QT_CONFIG(tooltip)
        showDerivative2->setToolTip(tr2i18n("Show second derivative", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        showDerivative2->setWhatsThis(tr2i18n("If this box is checked, the first derivative will be plotted, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        showDerivative2->setText(tr2i18n("Show &2nd derivative", nullptr));
        cartesian_f2->setTitle(tr2i18n("2nd derivative", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Derivatives", nullptr));
#if QT_CONFIG(tooltip)
        showIntegral->setToolTip(tr2i18n("Show integral", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        showIntegral->setWhatsThis(tr2i18n("If this box is checked, the integral will be plotted, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        showIntegral->setText(tr2i18n("Show integral", nullptr));
#if QT_CONFIG(tooltip)
        groupBox_6->setToolTip(tr2i18n("A point on the solution curve", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_6->setTitle(tr2i18n("Initial Point", nullptr));
        textLabel1_5->setText(tr2i18n("&x:", nullptr));
        textLabel1_5_2->setText(tr2i18n("&y:", nullptr));
#if QT_CONFIG(tooltip)
        txtInitX->setToolTip(tr2i18n("Enter the initial x-point,for instance 2 or pi", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        txtInitX->setWhatsThis(tr2i18n("Enter the initial x-value or expression for the integral, for example 2 or pi/2", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        txtInitY->setToolTip(tr2i18n("enter the initial y-point, eg 2 or pi", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        txtInitY->setWhatsThis(tr2i18n("Enter the initial y-value or expression for the integral, for example 2 or pi/2", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        groupBox_8->setToolTip(tr2i18n("The maximum step size used in numerically calculating the solution", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_8->setTitle(tr2i18n("Precision", nullptr));
        label_6->setText(tr2i18n("Step:", nullptr));
        cartesian_integral->setTitle(tr2i18n("Appearance", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Integral", nullptr));
        groupBox_11->setTitle(tr2i18n("Definition", nullptr));
        textLabelX->setText(tr2i18n("x:", nullptr));
#if QT_CONFIG(tooltip)
        parametricX->setToolTip(tr2i18n("Enter an expression", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        parametricX->setWhatsThis(tr2i18n("Enter an expression for the function.\n"
"The dummy variable is t.\n"
"Example: cos(t)", nullptr));
#endif // QT_CONFIG(whatsthis)
        parametricX->setText(QString());
        textLabelY->setText(tr2i18n("y:", nullptr));
#if QT_CONFIG(tooltip)
        parametricY->setToolTip(tr2i18n("Enter an expression", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        parametricY->setWhatsThis(tr2i18n("Enter an expression for the function.\n"
"The dummy variable is t.\n"
"Example: sin(t)", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_9->setTitle(tr2i18n("Plot range", nullptr));
        label->setText(tr2i18n("Min:", nullptr));
        label_2->setText(tr2i18n("Max:", nullptr));
#if QT_CONFIG(tooltip)
        parametricMin->setToolTip(tr2i18n("Lower boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        parametricMin->setWhatsThis(tr2i18n("Enter the lower boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        parametricMax->setToolTip(tr2i18n("Upper boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        parametricMax->setWhatsThis(tr2i18n("Enter the upper boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        parametricParameters->setTitle(tr2i18n("Parameters", nullptr));
        parametric_f0->setTitle(tr2i18n("Appearance", nullptr));
        groupBox_2->setTitle(tr2i18n("Definition", nullptr));
#if QT_CONFIG(tooltip)
        polarEquation->setToolTip(tr2i18n("Enter an equation", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        polarEquation->setWhatsThis(tr2i18n("Enter an expression for the function. \n"
"Example: loop(a)=ln(a)", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_13->setTitle(tr2i18n("Plot Range", nullptr));
#if QT_CONFIG(tooltip)
        polarMin->setToolTip(tr2i18n("Lower boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        polarMin->setWhatsThis(tr2i18n("Enter the lower boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        polarMax->setToolTip(tr2i18n("Upper boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        polarMax->setWhatsThis(tr2i18n("Enter the upper boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Min:", nullptr));
        label_4->setText(tr2i18n("Max:", nullptr));
        polarParameters->setTitle(tr2i18n("Parameters", nullptr));
        polar_f0->setTitle(tr2i18n("Appearance", nullptr));
        groupBox_12->setTitle(tr2i18n("Definition", nullptr));
#if QT_CONFIG(tooltip)
        implicitName->setToolTip(tr2i18n("Name of the function", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        implicitName->setWhatsThis(tr2i18n("Enter the name of the function.\n"
"The name of a function must be unique. If you leave this line empty KmPlot will set a default name. You can change it later.", nullptr));
#endif // QT_CONFIG(whatsthis)
        implicitName->setText(tr2i18n("f(x,y)", nullptr));
        textLabel4_2->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        implicitEquation->setToolTip(tr2i18n("Enter an expression", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        implicitEquation->setWhatsThis(tr2i18n("Enter an expression for the function.\n"
"Example: x^2 + y^2 = 25.", nullptr));
#endif // QT_CONFIG(whatsthis)
        implicitParameters->setTitle(tr2i18n("Parameters", nullptr));
        implicit_f0->setTitle(tr2i18n("Appearance", nullptr));
#if QT_CONFIG(tooltip)
        differentialEquation->setToolTip(tr2i18n("Enter an expression", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        differentialEquation->setWhatsThis(tr2i18n("Enter an expression for the function.\n"
"Example: f''(x) = -f", nullptr));
#endif // QT_CONFIG(whatsthis)
        differentialEquation->setText(tr2i18n("f''(x) = -f", nullptr));
#if QT_CONFIG(tooltip)
        groupBox_10->setToolTip(tr2i18n("The maximum step size used in numerically calculating the solution", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_10->setTitle(tr2i18n("Precision", nullptr));
        label_7->setText(tr2i18n("Step:", nullptr));
        differentialParameters->setTitle(tr2i18n("Parameters", nullptr));
        differential_f0->setTitle(tr2i18n("Appearance", nullptr));
        differentialTabWidget->setTabText(differentialTabWidget->indexOf(tab_4), tr2i18n("Function", nullptr));
        differentialTabWidget->setTabText(differentialTabWidget->indexOf(tab_5), tr2i18n("Initial Conditions", nullptr));
        (void)FunctionEditorWidget;
    } // retranslateUi

};

namespace Ui {
    class FunctionEditorWidget: public Ui_FunctionEditorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FUNCTIONEDITORWIDGET_H

