/********************************************************************************
** Form generated from reading UI file 'parameteranimator.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARAMETERANIMATOR_H
#define UI_PARAMETERANIMATOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ParameterAnimator
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *warningLabel;
    QGridLayout *gridLayout;
    QLabel *label_2;
    EquationEdit *step;
    EquationEdit *final;
    QLabel *label_3;
    EquationEdit *initial;
    QLabel *label;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout;
    QLabel *label_4;
    QLabel *currentValue;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QToolButton *gotoInitial;
    QToolButton *stepBackwards;
    QToolButton *pause;
    QToolButton *stepForwards;
    QToolButton *gotoFinal;
    QSpacerItem *spacerItem3;
    QSpacerItem *spacerItem4;
    QHBoxLayout *hboxLayout2;
    QLabel *label_5;
    QGridLayout *gridLayout1;
    QSlider *speed;
    QSpacerItem *spacerItem5;
    QLabel *label_7;
    QLabel *label_6;
    QSpacerItem *spacerItem6;

    void setupUi(QWidget *ParameterAnimator)
    {
        if (ParameterAnimator->objectName().isEmpty())
            ParameterAnimator->setObjectName("ParameterAnimator");
        ParameterAnimator->resize(411, 460);
        vboxLayout = new QVBoxLayout(ParameterAnimator);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        warningLabel = new QLabel(ParameterAnimator);
        warningLabel->setObjectName("warningLabel");
        warningLabel->setWordWrap(true);

        vboxLayout->addWidget(warningLabel);

        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(ParameterAnimator);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        step = new EquationEdit(ParameterAnimator);
        step->setObjectName("step");

        gridLayout->addWidget(step, 2, 1, 1, 1);

        final = new EquationEdit(ParameterAnimator);
        final->setObjectName("final");

        gridLayout->addWidget(final, 1, 1, 1, 1);

        label_3 = new QLabel(ParameterAnimator);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        initial = new EquationEdit(ParameterAnimator);
        initial->setObjectName("initial");

        gridLayout->addWidget(initial, 0, 1, 1, 1);

        label = new QLabel(ParameterAnimator);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);


        vboxLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        label_4 = new QLabel(ParameterAnimator);
        label_4->setObjectName("label_4");

        hboxLayout->addWidget(label_4);

        currentValue = new QLabel(ParameterAnimator);
        currentValue->setObjectName("currentValue");

        hboxLayout->addWidget(currentValue);


        vboxLayout->addLayout(hboxLayout);

        spacerItem1 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem1);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        spacerItem2 = new QSpacerItem(96, 25, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        gotoInitial = new QToolButton(ParameterAnimator);
        gotoInitial->setObjectName("gotoInitial");

        hboxLayout1->addWidget(gotoInitial);

        stepBackwards = new QToolButton(ParameterAnimator);
        stepBackwards->setObjectName("stepBackwards");
        stepBackwards->setCheckable(true);

        hboxLayout1->addWidget(stepBackwards);

        pause = new QToolButton(ParameterAnimator);
        pause->setObjectName("pause");

        hboxLayout1->addWidget(pause);

        stepForwards = new QToolButton(ParameterAnimator);
        stepForwards->setObjectName("stepForwards");
        stepForwards->setCheckable(true);

        hboxLayout1->addWidget(stepForwards);

        gotoFinal = new QToolButton(ParameterAnimator);
        gotoFinal->setObjectName("gotoFinal");

        hboxLayout1->addWidget(gotoFinal);

        spacerItem3 = new QSpacerItem(96, 25, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem3);


        vboxLayout->addLayout(hboxLayout1);

        spacerItem4 = new QSpacerItem(20, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        vboxLayout->addItem(spacerItem4);

        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        label_5 = new QLabel(ParameterAnimator);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        hboxLayout2->addWidget(label_5);

        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        speed = new QSlider(ParameterAnimator);
        speed->setObjectName("speed");
        speed->setMinimum(1);
        speed->setMaximum(100);
        speed->setValue(50);
        speed->setOrientation(Qt::Horizontal);

        gridLayout1->addWidget(speed, 0, 0, 1, 3);

        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(spacerItem5, 1, 1, 1, 1);

        label_7 = new QLabel(ParameterAnimator);
        label_7->setObjectName("label_7");

        gridLayout1->addWidget(label_7, 1, 2, 1, 1);

        label_6 = new QLabel(ParameterAnimator);
        label_6->setObjectName("label_6");

        gridLayout1->addWidget(label_6, 1, 0, 1, 1);


        hboxLayout2->addLayout(gridLayout1);


        vboxLayout->addLayout(hboxLayout2);

        spacerItem6 = new QSpacerItem(261, 81, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem6);

        QWidget::setTabOrder(initial, final);
        QWidget::setTabOrder(final, step);
        QWidget::setTabOrder(step, gotoInitial);
        QWidget::setTabOrder(gotoInitial, stepBackwards);
        QWidget::setTabOrder(stepBackwards, pause);
        QWidget::setTabOrder(pause, stepForwards);
        QWidget::setTabOrder(stepForwards, gotoFinal);
        QWidget::setTabOrder(gotoFinal, speed);

        retranslateUi(ParameterAnimator);

        QMetaObject::connectSlotsByName(ParameterAnimator);
    } // setupUi

    void retranslateUi(QWidget *ParameterAnimator)
    {
#if QT_CONFIG(tooltip)
        warningLabel->setToolTip(tr2i18n("The function must have an additional variable as a parameter, e.g. f(x,k) would have k as its parameter", nullptr));
#endif // QT_CONFIG(tooltip)
        warningLabel->setText(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:Sans;\"><span style=\" font-weight:600;\">Warning:</span> The current function does not have a parameter, and so cannot be animated.</p></body></html>", nullptr));
        label_2->setText(tr2i18n("Final value:", nullptr));
        step->setText(tr2i18n("1", nullptr));
        final->setText(tr2i18n("10", nullptr));
        label_3->setText(tr2i18n("Step:", nullptr));
        initial->setText(tr2i18n("0", nullptr));
        label->setText(tr2i18n("Initial value:", nullptr));
        label_4->setText(tr2i18n("Current Value:", nullptr));
        currentValue->setText(tr2i18n("0", nullptr));
        gotoInitial->setText(tr2i18n("<<", nullptr));
        stepBackwards->setText(tr2i18n("<", nullptr));
        pause->setText(tr2i18n("||", nullptr));
        stepForwards->setText(tr2i18n(">", nullptr));
        gotoFinal->setText(tr2i18n(">>", nullptr));
        label_5->setText(tr2i18n("Speed:", nullptr));
        label_7->setText(tr2i18n("Fast", nullptr));
        label_6->setText(tr2i18n("Slow", nullptr));
        (void)ParameterAnimator;
    } // retranslateUi

};

namespace Ui {
    class ParameterAnimator: public Ui_ParameterAnimator {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARAMETERANIMATOR_H

