/********************************************************************************
** Form generated from reading UI file 'functiontools.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FUNCTIONTOOLS_H
#define UI_FUNCTIONTOOLS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_FunctionTools
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *rangeTitle;
    QLabel *label_4;
    EquationEdit *min;
    QLabel *label_5;
    EquationEdit *max;
    QLabel *rangeResult;
    QListWidget *list;

    void setupUi(QWidget *FunctionTools)
    {
        if (FunctionTools->objectName().isEmpty())
            FunctionTools->setObjectName("FunctionTools");
        FunctionTools->resize(418, 354);
        vboxLayout = new QVBoxLayout(FunctionTools);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        rangeTitle = new QLabel(FunctionTools);
        rangeTitle->setObjectName("rangeTitle");

        gridLayout->addWidget(rangeTitle, 0, 0, 1, 2);

        label_4 = new QLabel(FunctionTools);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        min = new EquationEdit(FunctionTools);
        min->setObjectName("min");

        gridLayout->addWidget(min, 1, 1, 1, 1);

        label_5 = new QLabel(FunctionTools);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        max = new EquationEdit(FunctionTools);
        max->setObjectName("max");

        gridLayout->addWidget(max, 2, 1, 1, 1);

        rangeResult = new QLabel(FunctionTools);
        rangeResult->setObjectName("rangeResult");
        rangeResult->setAlignment(Qt::AlignCenter);
        rangeResult->setTextInteractionFlags(Qt::TextSelectableByMouse);

        gridLayout->addWidget(rangeResult, 3, 0, 1, 2);


        vboxLayout->addLayout(gridLayout);

        list = new QListWidget(FunctionTools);
        list->setObjectName("list");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(list->sizePolicy().hasHeightForWidth());
        list->setSizePolicy(sizePolicy);

        vboxLayout->addWidget(list);


        retranslateUi(FunctionTools);

        QMetaObject::connectSlotsByName(FunctionTools);
    } // setupUi

    void retranslateUi(QWidget *FunctionTools)
    {
        FunctionTools->setWindowTitle(tr2i18n("Function Tools", nullptr));
        rangeTitle->setText(tr2i18n("<>:", nullptr));
        label_4->setText(tr2i18n("Min:", nullptr));
#if QT_CONFIG(tooltip)
        min->setToolTip(tr2i18n("Lower boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        min->setWhatsThis(tr2i18n("Enter the lower boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_5->setText(tr2i18n("Max:", nullptr));
#if QT_CONFIG(tooltip)
        max->setToolTip(tr2i18n("Upper boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        max->setWhatsThis(tr2i18n("Enter the upper boundary of the plot range. Expressions like 2*pi are allowed, too.", nullptr));
#endif // QT_CONFIG(whatsthis)
        rangeResult->setText(tr2i18n("<>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FunctionTools: public Ui_FunctionTools {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FUNCTIONTOOLS_H

