/********************************************************************************
** Form generated from reading UI file 'settingspagegeneral.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSPAGEGENERAL_H
#define UI_SETTINGSPAGEGENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsPageGeneral
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kcfg_anglemode;
    QVBoxLayout *vboxLayout;
    QRadioButton *radioButton1;
    QRadioButton *radioButton2;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout;
    QLabel *textLabel1_2;
    QLabel *textLabel1_2_2;
    QSpinBox *kcfg_zoomOutStep;
    QSpinBox *kcfg_zoomInStep;
    QCheckBox *kcfg_DetailedTracing;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SettingsPageGeneral)
    {
        if (SettingsPageGeneral->objectName().isEmpty())
            SettingsPageGeneral->setObjectName("SettingsPageGeneral");
        SettingsPageGeneral->resize(342, 348);
        verticalLayout = new QVBoxLayout(SettingsPageGeneral);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_anglemode = new QGroupBox(SettingsPageGeneral);
        kcfg_anglemode->setObjectName("kcfg_anglemode");
        vboxLayout = new QVBoxLayout(kcfg_anglemode);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        radioButton1 = new QRadioButton(kcfg_anglemode);
        radioButton1->setObjectName("radioButton1");

        vboxLayout->addWidget(radioButton1);

        radioButton2 = new QRadioButton(kcfg_anglemode);
        radioButton2->setObjectName("radioButton2");

        vboxLayout->addWidget(radioButton2);


        verticalLayout->addWidget(kcfg_anglemode);

        groupBox_4 = new QGroupBox(SettingsPageGeneral);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout = new QGridLayout(groupBox_4);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel1_2 = new QLabel(groupBox_4);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel1_2, 0, 0, 1, 1);

        textLabel1_2_2 = new QLabel(groupBox_4);
        textLabel1_2_2->setObjectName("textLabel1_2_2");
        textLabel1_2_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel1_2_2, 1, 0, 1, 1);

        kcfg_zoomOutStep = new QSpinBox(groupBox_4);
        kcfg_zoomOutStep->setObjectName("kcfg_zoomOutStep");
        kcfg_zoomOutStep->setValue(25);
        kcfg_zoomOutStep->setMinimum(1);
        kcfg_zoomOutStep->setMaximum(100);

        gridLayout->addWidget(kcfg_zoomOutStep, 1, 1, 1, 1);

        kcfg_zoomInStep = new QSpinBox(groupBox_4);
        kcfg_zoomInStep->setObjectName("kcfg_zoomInStep");
        kcfg_zoomInStep->setValue(25);
        kcfg_zoomInStep->setMinimum(1);
        kcfg_zoomInStep->setMaximum(100);

        gridLayout->addWidget(kcfg_zoomInStep, 0, 1, 1, 1);

        textLabel1_2->raise();
        textLabel1_2_2->raise();
        kcfg_zoomOutStep->raise();
        kcfg_zoomInStep->raise();

        verticalLayout->addWidget(groupBox_4);

        kcfg_DetailedTracing = new QCheckBox(SettingsPageGeneral);
        kcfg_DetailedTracing->setObjectName("kcfg_DetailedTracing");

        verticalLayout->addWidget(kcfg_DetailedTracing);

        spacerItem = new QSpacerItem(221, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        textLabel1_2->setBuddy(kcfg_zoomInStep);
        textLabel1_2_2->setBuddy(kcfg_zoomOutStep);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SettingsPageGeneral);

        QMetaObject::connectSlotsByName(SettingsPageGeneral);
    } // setupUi

    void retranslateUi(QWidget *SettingsPageGeneral)
    {
        SettingsPageGeneral->setWindowTitle(tr2i18n("General", nullptr));
        kcfg_anglemode->setTitle(tr2i18n("Angle Mode", nullptr));
#if QT_CONFIG(tooltip)
        radioButton1->setToolTip(tr2i18n("Trigonometric functions use radian mode for angles.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        radioButton1->setWhatsThis(tr2i18n("Check this button to use radian mode to measure angles. This is important for trigonometric functions only.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioButton1->setText(tr2i18n("&Radian", nullptr));
#if QT_CONFIG(tooltip)
        radioButton2->setToolTip(tr2i18n("Trigonometric functions use degree mode for angles.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        radioButton2->setWhatsThis(tr2i18n("Check this button to use degree mode to measure angles. This is important for trigonometric functions only.", nullptr));
#endif // QT_CONFIG(whatsthis)
        radioButton2->setText(tr2i18n("&Degree", nullptr));
        groupBox_4->setTitle(tr2i18n("Zoom", nullptr));
        textLabel1_2->setText(tr2i18n("Zoom in by:", nullptr));
        textLabel1_2_2->setText(tr2i18n("Zoom out by:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_zoomOutStep->setWhatsThis(tr2i18n("The value the Zoom Out tool should use.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_zoomOutStep->setSuffix(tr2i18n("%", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_zoomInStep->setWhatsThis(tr2i18n("The value the Zoom In tool should use.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_zoomInStep->setSuffix(tr2i18n("%", nullptr));
        kcfg_DetailedTracing->setText(tr2i18n("Draw tangent and normal when tracing", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsPageGeneral: public Ui_SettingsPageGeneral {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSPAGEGENERAL_H

