/********************************************************************************
** Form generated from reading UI file 'plotstylewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLOTSTYLEWIDGET_H
#define UI_PLOTSTYLEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kgradientdialog.h"

QT_BEGIN_NAMESPACE

class Ui_PlotStyleWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *showPlotName;
    QCheckBox *showExtrema;
    QSpacerItem *spacerItem;
    QCheckBox *showTangentField;
    KGradientButton *gradientButton;
    QCheckBox *useGradient;
    QLabel *label_2;
    QComboBox *lineStyle;
    QLabel *label;
    QDoubleSpinBox *lineWidth;

    void setupUi(QWidget *PlotStyleWidget)
    {
        if (PlotStyleWidget->objectName().isEmpty())
            PlotStyleWidget->setObjectName("PlotStyleWidget");
        PlotStyleWidget->resize(385, 305);
        gridLayout = new QGridLayout(PlotStyleWidget);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        showPlotName = new QCheckBox(PlotStyleWidget);
        showPlotName->setObjectName("showPlotName");

        gridLayout->addWidget(showPlotName, 5, 0, 1, 3);

        showExtrema = new QCheckBox(PlotStyleWidget);
        showExtrema->setObjectName("showExtrema");

        gridLayout->addWidget(showExtrema, 4, 0, 1, 3);

        spacerItem = new QSpacerItem(106, 61, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 6, 0, 1, 1);

        showTangentField = new QCheckBox(PlotStyleWidget);
        showTangentField->setObjectName("showTangentField");

        gridLayout->addWidget(showTangentField, 3, 0, 1, 3);

        gradientButton = new KGradientButton(PlotStyleWidget);
        gradientButton->setObjectName("gradientButton");
        gradientButton->setEnabled(false);

        gridLayout->addWidget(gradientButton, 2, 2, 1, 1);

        useGradient = new QCheckBox(PlotStyleWidget);
        useGradient->setObjectName("useGradient");

        gridLayout->addWidget(useGradient, 2, 0, 1, 2);

        label_2 = new QLabel(PlotStyleWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        lineStyle = new QComboBox(PlotStyleWidget);
        lineStyle->setObjectName("lineStyle");

        gridLayout->addWidget(lineStyle, 1, 1, 1, 2);

        label = new QLabel(PlotStyleWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        lineWidth = new QDoubleSpinBox(PlotStyleWidget);
        lineWidth->setObjectName("lineWidth");
        lineWidth->setAlignment(Qt::AlignRight);
        lineWidth->setDecimals(1);
        lineWidth->setMinimum(0.100000000000000);
        lineWidth->setSingleStep(0.100000000000000);

        gridLayout->addWidget(lineWidth, 0, 1, 1, 2);

#if QT_CONFIG(shortcut)
        label->setBuddy(lineStyle);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(lineStyle, lineWidth);

        retranslateUi(PlotStyleWidget);
        QObject::connect(useGradient, SIGNAL(toggled(bool)), gradientButton, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(PlotStyleWidget);
    } // setupUi

    void retranslateUi(QWidget *PlotStyleWidget)
    {
        PlotStyleWidget->setWindowTitle(tr2i18n("Plot Style", nullptr));
        showPlotName->setText(tr2i18n("Show the plot name", nullptr));
        showExtrema->setText(tr2i18n("Show extrema (minimum/maximum points)", nullptr));
        showTangentField->setText(tr2i18n("Show the tangent field:", nullptr));
        useGradient->setText(tr2i18n("Use a gradient for parameters:", nullptr));
        label_2->setText(tr2i18n("Line style:", nullptr));
        label->setText(tr2i18n("Line width:", nullptr));
        lineWidth->setSuffix(tr2i18n(" mm", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PlotStyleWidget: public Ui_PlotStyleWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLOTSTYLEWIDGET_H

