/********************************************************************************
** Form generated from reading UI file 'editcoords.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITCOORDS_H
#define UI_EDITCOORDS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_EditCoords
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *textLabel4_2;
    EquationEdit *kcfg_XMax;
    EquationEdit *kcfg_XMin;
    QLabel *textLabel4;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout1;
    EquationEdit *kcfg_YMax;
    QLabel *textLabel4_4;
    QLabel *textLabel4_3;
    EquationEdit *kcfg_YMin;
    QGroupBox *kcfg_XScalingMode;
    QGridLayout *gridLayout2;
    QRadioButton *radioButton;
    QRadioButton *radioButton_2;
    EquationEdit *kcfg_XScaling;
    QGroupBox *kcfg_YScalingMode;
    QGridLayout *gridLayout3;
    QRadioButton *radioButton_3;
    QRadioButton *radioButton_4;
    EquationEdit *kcfg_YScaling;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *EditCoords)
    {
        if (EditCoords->objectName().isEmpty())
            EditCoords->setObjectName("EditCoords");
        EditCoords->setEnabled(true);
        EditCoords->resize(527, 470);
        vboxLayout = new QVBoxLayout(EditCoords);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(EditCoords);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        textLabel4_2 = new QLabel(groupBox);
        textLabel4_2->setObjectName("textLabel4_2");
        textLabel4_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel4_2, 1, 0, 1, 1);

        kcfg_XMax = new EquationEdit(groupBox);
        kcfg_XMax->setObjectName("kcfg_XMax");

        gridLayout->addWidget(kcfg_XMax, 1, 1, 1, 1);

        kcfg_XMin = new EquationEdit(groupBox);
        kcfg_XMin->setObjectName("kcfg_XMin");

        gridLayout->addWidget(kcfg_XMin, 0, 1, 1, 1);

        textLabel4 = new QLabel(groupBox);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel4, 0, 0, 1, 1);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(EditCoords);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout1 = new QGridLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout1->setObjectName("gridLayout1");
        kcfg_YMax = new EquationEdit(groupBox_2);
        kcfg_YMax->setObjectName("kcfg_YMax");

        gridLayout1->addWidget(kcfg_YMax, 1, 1, 1, 1);

        textLabel4_4 = new QLabel(groupBox_2);
        textLabel4_4->setObjectName("textLabel4_4");
        textLabel4_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel4_4, 0, 0, 1, 1);

        textLabel4_3 = new QLabel(groupBox_2);
        textLabel4_3->setObjectName("textLabel4_3");
        textLabel4_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel4_3, 1, 0, 1, 1);

        kcfg_YMin = new EquationEdit(groupBox_2);
        kcfg_YMin->setObjectName("kcfg_YMin");

        gridLayout1->addWidget(kcfg_YMin, 0, 1, 1, 1);


        vboxLayout->addWidget(groupBox_2);

        kcfg_XScalingMode = new QGroupBox(EditCoords);
        kcfg_XScalingMode->setObjectName("kcfg_XScalingMode");
        gridLayout2 = new QGridLayout(kcfg_XScalingMode);
        gridLayout2->setObjectName("gridLayout2");
        radioButton = new QRadioButton(kcfg_XScalingMode);
        radioButton->setObjectName("radioButton");
        radioButton->setChecked(true);

        gridLayout2->addWidget(radioButton, 0, 0, 1, 2);

        radioButton_2 = new QRadioButton(kcfg_XScalingMode);
        radioButton_2->setObjectName("radioButton_2");

        gridLayout2->addWidget(radioButton_2, 1, 0, 1, 1);

        kcfg_XScaling = new EquationEdit(kcfg_XScalingMode);
        kcfg_XScaling->setObjectName("kcfg_XScaling");
        kcfg_XScaling->setEnabled(false);

        gridLayout2->addWidget(kcfg_XScaling, 1, 1, 1, 1);


        vboxLayout->addWidget(kcfg_XScalingMode);

        kcfg_YScalingMode = new QGroupBox(EditCoords);
        kcfg_YScalingMode->setObjectName("kcfg_YScalingMode");
        gridLayout3 = new QGridLayout(kcfg_YScalingMode);
        gridLayout3->setObjectName("gridLayout3");
        radioButton_3 = new QRadioButton(kcfg_YScalingMode);
        radioButton_3->setObjectName("radioButton_3");
        radioButton_3->setChecked(true);

        gridLayout3->addWidget(radioButton_3, 0, 0, 1, 2);

        radioButton_4 = new QRadioButton(kcfg_YScalingMode);
        radioButton_4->setObjectName("radioButton_4");

        gridLayout3->addWidget(radioButton_4, 1, 0, 1, 1);

        kcfg_YScaling = new EquationEdit(kcfg_YScalingMode);
        kcfg_YScaling->setObjectName("kcfg_YScaling");
        kcfg_YScaling->setEnabled(false);

        gridLayout3->addWidget(kcfg_YScaling, 1, 1, 1, 1);


        vboxLayout->addWidget(kcfg_YScalingMode);

        spacerItem = new QSpacerItem(509, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        textLabel4_2->setBuddy(kcfg_XMax);
        textLabel4->setBuddy(kcfg_XMin);
        textLabel4_4->setBuddy(kcfg_YMin);
        textLabel4_3->setBuddy(kcfg_YMax);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_XMin, kcfg_XMax);
        QWidget::setTabOrder(kcfg_XMax, kcfg_YMin);
        QWidget::setTabOrder(kcfg_YMin, kcfg_YMax);
        QWidget::setTabOrder(kcfg_YMax, radioButton);
        QWidget::setTabOrder(radioButton, radioButton_2);
        QWidget::setTabOrder(radioButton_2, kcfg_XScaling);
        QWidget::setTabOrder(kcfg_XScaling, radioButton_3);
        QWidget::setTabOrder(radioButton_3, radioButton_4);
        QWidget::setTabOrder(radioButton_4, kcfg_YScaling);

        retranslateUi(EditCoords);
        QObject::connect(radioButton_2, SIGNAL(toggled(bool)), kcfg_XScaling, SLOT(setEnabled(bool)));
        QObject::connect(radioButton_4, SIGNAL(toggled(bool)), kcfg_YScaling, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(EditCoords);
    } // setupUi

    void retranslateUi(QWidget *EditCoords)
    {
        groupBox->setTitle(tr2i18n("Horizontal axis Range", nullptr));
        textLabel4_2->setText(tr2i18n("Max:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_XMax->setToolTip(tr2i18n("Custom boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XMax->setWhatsThis(tr2i18n("Enter a valid expression, for instance 2*pi or e/2.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        kcfg_XMin->setToolTip(tr2i18n("Custom boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_XMin->setWhatsThis(tr2i18n("Enter a valid expression, for instance 2*pi or e/2.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel4->setText(tr2i18n("Min:", nullptr));
        groupBox_2->setTitle(tr2i18n("Vertical axis Range", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_YMax->setToolTip(tr2i18n("Custom boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_YMax->setWhatsThis(tr2i18n("Enter a valid expression, for instance 2*pi or e/2.", nullptr));
#endif // QT_CONFIG(whatsthis)
        textLabel4_4->setText(tr2i18n("Min:", nullptr));
        textLabel4_3->setText(tr2i18n("Max:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_YMin->setToolTip(tr2i18n("Custom boundary of the plot range", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_YMin->setWhatsThis(tr2i18n("Enter a valid expression, for instance 2*pi or e/2.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_XScalingMode->setTitle(tr2i18n("Horizontal axis Grid Spacing", nullptr));
#if QT_CONFIG(tooltip)
        radioButton->setToolTip(tr2i18n("Automatic grid spacing is independent of zoom; there will be a fixed number of tics.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButton->setText(tr2i18n("Automatic", nullptr));
        radioButton_2->setText(tr2i18n("Custom:", nullptr));
        kcfg_YScalingMode->setTitle(tr2i18n("Vertical axis Grid Spacing", nullptr));
#if QT_CONFIG(tooltip)
        radioButton_3->setToolTip(tr2i18n("Automatic grid spacing is independent of zoom; there will be a fixed number of tics.", nullptr));
#endif // QT_CONFIG(tooltip)
        radioButton_3->setText(tr2i18n("Automatic", nullptr));
        radioButton_4->setText(tr2i18n("Custom:", nullptr));
        (void)EditCoords;
    } // retranslateUi

};

namespace Ui {
    class EditCoords: public Ui_EditCoords {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITCOORDS_H

