/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmplot.MainDlg.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "maindlgadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class MainDlgAdaptor
 */

MainDlgAdaptor::MainDlgAdaptor(MainDlg *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

MainDlgAdaptor::~MainDlgAdaptor()
{
    // destructor
}

void MainDlgAdaptor::calculator()
{
    // handle method call org.kde.kmplot.MainDlg.calculator
    parent()->calculator();
}

bool MainDlgAdaptor::checkModified()
{
    // handle method call org.kde.kmplot.MainDlg.checkModified
    return parent()->checkModified();
}

void MainDlgAdaptor::editAxes()
{
    // handle method call org.kde.kmplot.MainDlg.editAxes
    parent()->editAxes();
}

void MainDlgAdaptor::findMaximumValue()
{
    // handle method call org.kde.kmplot.MainDlg.findMaximumValue
    parent()->findMaximumValue();
}

void MainDlgAdaptor::findMinimumValue()
{
    // handle method call org.kde.kmplot.MainDlg.findMinimumValue
    parent()->findMinimumValue();
}

void MainDlgAdaptor::graphArea()
{
    // handle method call org.kde.kmplot.MainDlg.graphArea
    parent()->graphArea();
}

bool MainDlgAdaptor::isModified()
{
    // handle method call org.kde.kmplot.MainDlg.isModified
    return parent()->isModified();
}

void MainDlgAdaptor::slotExport()
{
    // handle method call org.kde.kmplot.MainDlg.slotExport
    parent()->slotExport();
}

void MainDlgAdaptor::slotNames()
{
    // handle method call org.kde.kmplot.MainDlg.slotNames
    parent()->slotNames();
}

void MainDlgAdaptor::slotPrint()
{
    // handle method call org.kde.kmplot.MainDlg.slotPrint
    parent()->slotPrint();
}

void MainDlgAdaptor::slotResetView()
{
    // handle method call org.kde.kmplot.MainDlg.slotResetView
    parent()->slotResetView();
}

void MainDlgAdaptor::slotSave()
{
    // handle method call org.kde.kmplot.MainDlg.slotSave
    parent()->slotSave();
}

void MainDlgAdaptor::slotSaveas()
{
    // handle method call org.kde.kmplot.MainDlg.slotSaveas
    parent()->slotSaveas();
}

void MainDlgAdaptor::slotSettings()
{
    // handle method call org.kde.kmplot.MainDlg.slotSettings
    parent()->slotSettings();
}

void MainDlgAdaptor::toggleShowSliders()
{
    // handle method call org.kde.kmplot.MainDlg.toggleShowSliders
    parent()->toggleShowSliders();
}


#include "moc_maindlgadaptor.cpp"
