/********************************************************************************
** Form generated from reading UI file 'equationeditorwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EQUATIONEDITORWIDGET_H
#define UI_EQUATIONEDITORWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_EquationEditorWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    EquationEdit *edit;
    QHBoxLayout *hboxLayout1;
    QPushButton *constantsButton;
    QSpacerItem *spacerItem;
    QComboBox *constantList;
    QComboBox *functionList;
    QHBoxLayout *hboxLayout2;
    QSpacerItem *spacerItem1;
    QGridLayout *gridLayout;
    QToolButton *toolButton_3;
    QToolButton *toolButton_26;
    QToolButton *toolButton_28;
    QToolButton *toolButton_20;
    QToolButton *toolButton_4;
    QToolButton *toolButton_18;
    QToolButton *toolButton_19;
    QToolButton *toolButton_27;
    QToolButton *toolButton_25;
    QToolButton *toolButton_5;
    QSpacerItem *spacerItem2;
    QGridLayout *gridLayout1;
    QToolButton *toolButton_2;
    QToolButton *toolButton_29;
    QToolButton *toolButton_16;
    QToolButton *toolButton_12;
    QToolButton *toolButton_14;
    QToolButton *toolButton;
    QToolButton *toolButton_13;
    QToolButton *toolButton_15;
    QToolButton *toolButton_11;
    QSpacerItem *spacerItem3;
    QGridLayout *gridLayout2;
    QToolButton *toolButton_24;
    QToolButton *toolButton_21;
    QToolButton *toolButton_8;
    QToolButton *toolButton_9;
    QToolButton *toolButton_22;
    QToolButton *toolButton_23;
    QToolButton *toolButton_10;
    QToolButton *toolButton_7;
    QToolButton *toolButton_6;
    QToolButton *toolButton_17;
    QSpacerItem *spacerItem4;
    QSpacerItem *spacerItem5;

    void setupUi(QWidget *EquationEditorWidget)
    {
        if (EquationEditorWidget->objectName().isEmpty())
            EquationEditorWidget->setObjectName("EquationEditorWidget");
        EquationEditorWidget->resize(582, 182);
        vboxLayout = new QVBoxLayout(EquationEditorWidget);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        label = new QLabel(EquationEditorWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hboxLayout->addWidget(label);

        edit = new EquationEdit(EquationEditorWidget);
        edit->setObjectName("edit");

        hboxLayout->addWidget(edit);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        constantsButton = new QPushButton(EquationEditorWidget);
        constantsButton->setObjectName("constantsButton");

        hboxLayout1->addWidget(constantsButton);

        spacerItem = new QSpacerItem(51, 27, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(spacerItem);

        constantList = new QComboBox(EquationEditorWidget);
        constantList->addItem(QString());
        constantList->setObjectName("constantList");

        hboxLayout1->addWidget(constantList);

        functionList = new QComboBox(EquationEditorWidget);
        functionList->addItem(QString());
        functionList->setObjectName("functionList");

        hboxLayout1->addWidget(functionList);


        vboxLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(0);
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        spacerItem1 = new QSpacerItem(16, 60, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem1);

        gridLayout = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout->setObjectName("gridLayout");
        toolButton_3 = new QToolButton(EquationEditorWidget);
        toolButton_3->setObjectName("toolButton_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(toolButton_3->sizePolicy().hasHeightForWidth());
        toolButton_3->setSizePolicy(sizePolicy);

        gridLayout->addWidget(toolButton_3, 0, 0, 1, 1);

        toolButton_26 = new QToolButton(EquationEditorWidget);
        toolButton_26->setObjectName("toolButton_26");

        gridLayout->addWidget(toolButton_26, 1, 4, 1, 1);

        toolButton_28 = new QToolButton(EquationEditorWidget);
        toolButton_28->setObjectName("toolButton_28");
        sizePolicy.setHeightForWidth(toolButton_28->sizePolicy().hasHeightForWidth());
        toolButton_28->setSizePolicy(sizePolicy);

        gridLayout->addWidget(toolButton_28, 0, 4, 1, 1);

        toolButton_20 = new QToolButton(EquationEditorWidget);
        toolButton_20->setObjectName("toolButton_20");

        gridLayout->addWidget(toolButton_20, 1, 3, 1, 1);

        toolButton_4 = new QToolButton(EquationEditorWidget);
        toolButton_4->setObjectName("toolButton_4");
        sizePolicy.setHeightForWidth(toolButton_4->sizePolicy().hasHeightForWidth());
        toolButton_4->setSizePolicy(sizePolicy);

        gridLayout->addWidget(toolButton_4, 0, 1, 1, 1);

        toolButton_18 = new QToolButton(EquationEditorWidget);
        toolButton_18->setObjectName("toolButton_18");
        sizePolicy.setHeightForWidth(toolButton_18->sizePolicy().hasHeightForWidth());
        toolButton_18->setSizePolicy(sizePolicy);

        gridLayout->addWidget(toolButton_18, 1, 2, 1, 1);

        toolButton_19 = new QToolButton(EquationEditorWidget);
        toolButton_19->setObjectName("toolButton_19");

        gridLayout->addWidget(toolButton_19, 1, 1, 1, 1);

        toolButton_27 = new QToolButton(EquationEditorWidget);
        toolButton_27->setObjectName("toolButton_27");

        gridLayout->addWidget(toolButton_27, 1, 0, 1, 1);

        toolButton_25 = new QToolButton(EquationEditorWidget);
        toolButton_25->setObjectName("toolButton_25");
        sizePolicy.setHeightForWidth(toolButton_25->sizePolicy().hasHeightForWidth());
        toolButton_25->setSizePolicy(sizePolicy);

        gridLayout->addWidget(toolButton_25, 0, 3, 1, 1);

        toolButton_5 = new QToolButton(EquationEditorWidget);
        toolButton_5->setObjectName("toolButton_5");
        sizePolicy.setHeightForWidth(toolButton_5->sizePolicy().hasHeightForWidth());
        toolButton_5->setSizePolicy(sizePolicy);

        gridLayout->addWidget(toolButton_5, 0, 2, 1, 1);


        hboxLayout2->addLayout(gridLayout);

        spacerItem2 = new QSpacerItem(16, 60, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem2);

        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        toolButton_2 = new QToolButton(EquationEditorWidget);
        toolButton_2->setObjectName("toolButton_2");
        sizePolicy.setHeightForWidth(toolButton_2->sizePolicy().hasHeightForWidth());
        toolButton_2->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(toolButton_2, 1, 1, 1, 1);

        toolButton_29 = new QToolButton(EquationEditorWidget);
        toolButton_29->setObjectName("toolButton_29");
        sizePolicy.setHeightForWidth(toolButton_29->sizePolicy().hasHeightForWidth());
        toolButton_29->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(toolButton_29, 1, 0, 1, 1);

        toolButton_16 = new QToolButton(EquationEditorWidget);
        toolButton_16->setObjectName("toolButton_16");

        gridLayout1->addWidget(toolButton_16, 1, 4, 1, 1);

        toolButton_12 = new QToolButton(EquationEditorWidget);
        toolButton_12->setObjectName("toolButton_12");

        gridLayout1->addWidget(toolButton_12, 0, 1, 1, 1);

        toolButton_14 = new QToolButton(EquationEditorWidget);
        toolButton_14->setObjectName("toolButton_14");

        gridLayout1->addWidget(toolButton_14, 0, 0, 1, 1);

        toolButton = new QToolButton(EquationEditorWidget);
        toolButton->setObjectName("toolButton");
        sizePolicy.setHeightForWidth(toolButton->sizePolicy().hasHeightForWidth());
        toolButton->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(toolButton, 0, 3, 1, 1);

        toolButton_13 = new QToolButton(EquationEditorWidget);
        toolButton_13->setObjectName("toolButton_13");
        sizePolicy.setHeightForWidth(toolButton_13->sizePolicy().hasHeightForWidth());
        toolButton_13->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(toolButton_13, 1, 2, 1, 1);

        toolButton_15 = new QToolButton(EquationEditorWidget);
        toolButton_15->setObjectName("toolButton_15");

        gridLayout1->addWidget(toolButton_15, 1, 3, 1, 1);

        toolButton_11 = new QToolButton(EquationEditorWidget);
        toolButton_11->setObjectName("toolButton_11");
        sizePolicy.setHeightForWidth(toolButton_11->sizePolicy().hasHeightForWidth());
        toolButton_11->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(toolButton_11, 0, 2, 1, 1);


        hboxLayout2->addLayout(gridLayout1);

        spacerItem3 = new QSpacerItem(16, 60, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem3);

        gridLayout2 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout2->setObjectName("gridLayout2");
        toolButton_24 = new QToolButton(EquationEditorWidget);
        toolButton_24->setObjectName("toolButton_24");

        gridLayout2->addWidget(toolButton_24, 1, 4, 1, 1);

        toolButton_21 = new QToolButton(EquationEditorWidget);
        toolButton_21->setObjectName("toolButton_21");

        gridLayout2->addWidget(toolButton_21, 0, 3, 1, 1);

        toolButton_8 = new QToolButton(EquationEditorWidget);
        toolButton_8->setObjectName("toolButton_8");

        gridLayout2->addWidget(toolButton_8, 0, 2, 1, 1);

        toolButton_9 = new QToolButton(EquationEditorWidget);
        toolButton_9->setObjectName("toolButton_9");

        gridLayout2->addWidget(toolButton_9, 1, 1, 1, 1);

        toolButton_22 = new QToolButton(EquationEditorWidget);
        toolButton_22->setObjectName("toolButton_22");

        gridLayout2->addWidget(toolButton_22, 0, 4, 1, 1);

        toolButton_23 = new QToolButton(EquationEditorWidget);
        toolButton_23->setObjectName("toolButton_23");

        gridLayout2->addWidget(toolButton_23, 1, 3, 1, 1);

        toolButton_10 = new QToolButton(EquationEditorWidget);
        toolButton_10->setObjectName("toolButton_10");

        gridLayout2->addWidget(toolButton_10, 1, 2, 1, 1);

        toolButton_7 = new QToolButton(EquationEditorWidget);
        toolButton_7->setObjectName("toolButton_7");

        gridLayout2->addWidget(toolButton_7, 0, 0, 1, 1);

        toolButton_6 = new QToolButton(EquationEditorWidget);
        toolButton_6->setObjectName("toolButton_6");

        gridLayout2->addWidget(toolButton_6, 0, 1, 1, 1);

        toolButton_17 = new QToolButton(EquationEditorWidget);
        toolButton_17->setObjectName("toolButton_17");

        gridLayout2->addWidget(toolButton_17, 1, 0, 1, 1);


        hboxLayout2->addLayout(gridLayout2);

        spacerItem4 = new QSpacerItem(16, 60, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout2->addItem(spacerItem4);


        vboxLayout->addLayout(hboxLayout2);

        spacerItem5 = new QSpacerItem(465, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem5);


        retranslateUi(EquationEditorWidget);

        QMetaObject::connectSlotsByName(EquationEditorWidget);
    } // setupUi

    void retranslateUi(QWidget *EquationEditorWidget)
    {
        label->setText(tr2i18n("Expression:", nullptr));
        constantsButton->setText(tr2i18n("Edit Constants...", nullptr));
        constantList->setItemText(0, tr2i18n("Insert constant...", nullptr));

        functionList->setItemText(0, tr2i18n("Insert function...", nullptr));

        toolButton_3->setText(tr2i18n("\302\262", nullptr));
        toolButton_26->setText(tr2i18n("\302\261", nullptr));
        toolButton_28->setText(tr2i18n("\342\201\266", nullptr));
        toolButton_20->setText(tr2i18n("\342\210\232", nullptr));
        toolButton_4->setText(tr2i18n("\302\263", nullptr));
        toolButton_18->setText(tr2i18n("\342\210\243", nullptr));
        toolButton_19->setText(tr2i18n("\342\211\245", nullptr));
        toolButton_27->setText(tr2i18n("\342\211\244", nullptr));
        toolButton_25->setText(tr2i18n("\342\201\265", nullptr));
        toolButton_5->setText(tr2i18n("\342\201\264", nullptr));
        toolButton_2->setText(tr2i18n("\317\200", nullptr));
        toolButton_29->setText(tr2i18n("\317\204", nullptr));
        toolButton_16->setText(tr2i18n("\317\211", nullptr));
        toolButton_12->setText(tr2i18n("\316\262", nullptr));
        toolButton_14->setText(tr2i18n("\316\261", nullptr));
        toolButton->setText(tr2i18n("\316\273", nullptr));
        toolButton_13->setText(tr2i18n("\316\274", nullptr));
        toolButton_15->setText(tr2i18n("\317\206", nullptr));
        toolButton_11->setText(tr2i18n("\316\270", nullptr));
        toolButton_24->setText(tr2i18n("\342\205\230", nullptr));
        toolButton_21->setText(tr2i18n("\342\205\225", nullptr));
        toolButton_8->setText(tr2i18n("\302\274", nullptr));
        toolButton_9->setText(tr2i18n("\342\205\224", nullptr));
        toolButton_22->setText(tr2i18n("\342\205\226", nullptr));
        toolButton_23->setText(tr2i18n("\342\205\227", nullptr));
        toolButton_10->setText(tr2i18n("\302\276", nullptr));
        toolButton_7->setText(tr2i18n("\302\275", nullptr));
        toolButton_6->setText(tr2i18n("\342\205\223", nullptr));
        toolButton_17->setText(tr2i18n("\342\205\231", nullptr));
        (void)EquationEditorWidget;
    } // retranslateUi

};

namespace Ui {
    class EquationEditorWidget: public Ui_EquationEditorWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EQUATIONEDITORWIDGET_H

