/********************************************************************************
** Form generated from reading UI file 'constantseditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONSTANTSEDITOR_H
#define UI_CONSTANTSEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "equationedit.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ConstantsEditor
{
public:
    QGridLayout *gridLayout;
    QLabel *valueInvalidLabel;
    QGridLayout *gridLayout1;
    KLineEdit *nameEdit;
    QLabel *label_2;
    QLabel *label;
    EquationEdit *valueEdit;
    QPushButton *cmdNew;
    QTreeWidget *constantList;
    QSpacerItem *spacerItem;
    QPushButton *cmdDelete;

    void setupUi(QWidget *ConstantsEditor)
    {
        if (ConstantsEditor->objectName().isEmpty())
            ConstantsEditor->setObjectName("ConstantsEditor");
        ConstantsEditor->resize(521, 442);
        gridLayout = new QGridLayout(ConstantsEditor);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        valueInvalidLabel = new QLabel(ConstantsEditor);
        valueInvalidLabel->setObjectName("valueInvalidLabel");
        valueInvalidLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(valueInvalidLabel, 0, 1, 1, 1);

        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        gridLayout1->setObjectName("gridLayout1");
        nameEdit = new KLineEdit(ConstantsEditor);
        nameEdit->setObjectName("nameEdit");

        gridLayout1->addWidget(nameEdit, 0, 1, 1, 1);

        label_2 = new QLabel(ConstantsEditor);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(label_2, 1, 0, 1, 1);

        label = new QLabel(ConstantsEditor);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        valueEdit = new EquationEdit(ConstantsEditor);
        valueEdit->setObjectName("valueEdit");

        gridLayout1->addWidget(valueEdit, 1, 1, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);

        cmdNew = new QPushButton(ConstantsEditor);
        cmdNew->setObjectName("cmdNew");

        gridLayout->addWidget(cmdNew, 1, 1, 1, 1);

        constantList = new QTreeWidget(ConstantsEditor);
        constantList->setObjectName("constantList");
        constantList->setRootIsDecorated(false);
        constantList->setColumnCount(4);

        gridLayout->addWidget(constantList, 1, 0, 3, 1);

        spacerItem = new QSpacerItem(20, 261, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);

        cmdDelete = new QPushButton(ConstantsEditor);
        cmdDelete->setObjectName("cmdDelete");
        cmdDelete->setEnabled(false);

        gridLayout->addWidget(cmdDelete, 2, 1, 1, 1);


        retranslateUi(ConstantsEditor);

        QMetaObject::connectSlotsByName(ConstantsEditor);
    } // setupUi

    void retranslateUi(QWidget *ConstantsEditor)
    {
        ConstantsEditor->setWindowTitle(tr2i18n("Constant Editor", nullptr));
#if QT_CONFIG(tooltip)
        valueInvalidLabel->setToolTip(tr2i18n("The value must be a number (e.g. \"pi^2\")", nullptr));
#endif // QT_CONFIG(tooltip)
        valueInvalidLabel->setText(tr2i18n("(invalid)", nullptr));
#if QT_CONFIG(whatsthis)
        nameEdit->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Value:", nullptr));
        label->setText(tr2i18n("Constant:", nullptr));
#if QT_CONFIG(tooltip)
        valueEdit->setToolTip(tr2i18n("Enter an expression that evaluates to a number", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cmdNew->setToolTip(tr2i18n("Add a new constant", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmdNew->setWhatsThis(tr2i18n("Click this button to add a new constant.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cmdNew->setText(tr2i18n("&New", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = constantList->headerItem();
        ___qtreewidgetitem->setText(3, tr2i18n("Global", nullptr));
        ___qtreewidgetitem->setText(2, tr2i18n("Document", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Value", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Constant", nullptr));
#if QT_CONFIG(tooltip)
        cmdDelete->setToolTip(tr2i18n("Delete the selected constant", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cmdDelete->setWhatsThis(tr2i18n("Click here to delete the selected constant; it can only be removed if it is not currently used by a plot.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cmdDelete->setText(tr2i18n("&Delete", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ConstantsEditor: public Ui_ConstantsEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONSTANTSEDITOR_H

