/********************************************************************************
** Form generated from reading UI file 'settingspagecolor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSPAGECOLOR_H
#define UI_SETTINGSPAGECOLOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_SettingsPageColor
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label;
    KColorButton *kcfg_backgroundcolor;
    QLabel *textLabel1;
    QLabel *textLabel2;
    KColorButton *kcfg_AxesColor;
    KColorButton *kcfg_GridColor;
    QGroupBox *groupBox_3;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout1;
    KColorButton *kcfg_Color1;
    KColorButton *kcfg_Color4;
    KColorButton *kcfg_Color0;
    QLabel *textLabel3;
    KColorButton *kcfg_Color2;
    QLabel *textLabel3_13;
    QLabel *textLabel3_2;
    QLabel *textLabel3_12;
    KColorButton *kcfg_Color3;
    QLabel *textLabel3_11;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout2;
    QLabel *textLabel3_9;
    QLabel *textLabel3_8;
    KColorButton *kcfg_Color8;
    QLabel *textLabel3_10;
    KColorButton *kcfg_Color6;
    KColorButton *kcfg_Color7;
    KColorButton *kcfg_Color5;
    QLabel *textLabel3_7;
    KColorButton *kcfg_Color9;
    QLabel *textLabel3_6;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *SettingsPageColor)
    {
        if (SettingsPageColor->objectName().isEmpty())
            SettingsPageColor->setObjectName("SettingsPageColor");
        SettingsPageColor->resize(455, 455);
        vboxLayout = new QVBoxLayout(SettingsPageColor);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName("vboxLayout");
        groupBox_2 = new QGroupBox(SettingsPageColor);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_backgroundcolor = new KColorButton(groupBox_2);
        kcfg_backgroundcolor->setObjectName("kcfg_backgroundcolor");

        gridLayout->addWidget(kcfg_backgroundcolor, 0, 1, 1, 1);

        textLabel1 = new QLabel(groupBox_2);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel1, 1, 0, 1, 1);

        textLabel2 = new QLabel(groupBox_2);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel2, 2, 0, 1, 1);

        kcfg_AxesColor = new KColorButton(groupBox_2);
        kcfg_AxesColor->setObjectName("kcfg_AxesColor");

        gridLayout->addWidget(kcfg_AxesColor, 1, 1, 1, 1);

        kcfg_GridColor = new KColorButton(groupBox_2);
        kcfg_GridColor->setObjectName("kcfg_GridColor");

        gridLayout->addWidget(kcfg_GridColor, 2, 1, 1, 1);


        vboxLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(SettingsPageColor);
        groupBox_3->setObjectName("groupBox_3");
        hboxLayout = new QHBoxLayout(groupBox_3);
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        hboxLayout->setObjectName("hboxLayout");
        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout1->setObjectName("gridLayout1");
        kcfg_Color1 = new KColorButton(groupBox_3);
        kcfg_Color1->setObjectName("kcfg_Color1");

        gridLayout1->addWidget(kcfg_Color1, 1, 1, 1, 1);

        kcfg_Color4 = new KColorButton(groupBox_3);
        kcfg_Color4->setObjectName("kcfg_Color4");

        gridLayout1->addWidget(kcfg_Color4, 4, 1, 1, 1);

        kcfg_Color0 = new KColorButton(groupBox_3);
        kcfg_Color0->setObjectName("kcfg_Color0");

        gridLayout1->addWidget(kcfg_Color0, 0, 1, 1, 1);

        textLabel3 = new QLabel(groupBox_3);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel3, 0, 0, 1, 1);

        kcfg_Color2 = new KColorButton(groupBox_3);
        kcfg_Color2->setObjectName("kcfg_Color2");

        gridLayout1->addWidget(kcfg_Color2, 2, 1, 1, 1);

        textLabel3_13 = new QLabel(groupBox_3);
        textLabel3_13->setObjectName("textLabel3_13");
        textLabel3_13->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel3_13, 2, 0, 1, 1);

        textLabel3_2 = new QLabel(groupBox_3);
        textLabel3_2->setObjectName("textLabel3_2");
        textLabel3_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel3_2, 1, 0, 1, 1);

        textLabel3_12 = new QLabel(groupBox_3);
        textLabel3_12->setObjectName("textLabel3_12");
        textLabel3_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel3_12, 3, 0, 1, 1);

        kcfg_Color3 = new KColorButton(groupBox_3);
        kcfg_Color3->setObjectName("kcfg_Color3");

        gridLayout1->addWidget(kcfg_Color3, 3, 1, 1, 1);

        textLabel3_11 = new QLabel(groupBox_3);
        textLabel3_11->setObjectName("textLabel3_11");
        textLabel3_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(textLabel3_11, 4, 0, 1, 1);


        hboxLayout->addLayout(gridLayout1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        gridLayout2 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout2->setObjectName("gridLayout2");
        textLabel3_9 = new QLabel(groupBox_3);
        textLabel3_9->setObjectName("textLabel3_9");
        textLabel3_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(textLabel3_9, 1, 0, 1, 1);

        textLabel3_8 = new QLabel(groupBox_3);
        textLabel3_8->setObjectName("textLabel3_8");
        textLabel3_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(textLabel3_8, 2, 0, 1, 1);

        kcfg_Color8 = new KColorButton(groupBox_3);
        kcfg_Color8->setObjectName("kcfg_Color8");

        gridLayout2->addWidget(kcfg_Color8, 3, 1, 1, 1);

        textLabel3_10 = new QLabel(groupBox_3);
        textLabel3_10->setObjectName("textLabel3_10");
        textLabel3_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(textLabel3_10, 0, 0, 1, 1);

        kcfg_Color6 = new KColorButton(groupBox_3);
        kcfg_Color6->setObjectName("kcfg_Color6");

        gridLayout2->addWidget(kcfg_Color6, 1, 1, 1, 1);

        kcfg_Color7 = new KColorButton(groupBox_3);
        kcfg_Color7->setObjectName("kcfg_Color7");

        gridLayout2->addWidget(kcfg_Color7, 2, 1, 1, 1);

        kcfg_Color5 = new KColorButton(groupBox_3);
        kcfg_Color5->setObjectName("kcfg_Color5");

        gridLayout2->addWidget(kcfg_Color5, 0, 1, 1, 1);

        textLabel3_7 = new QLabel(groupBox_3);
        textLabel3_7->setObjectName("textLabel3_7");
        textLabel3_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(textLabel3_7, 3, 0, 1, 1);

        kcfg_Color9 = new KColorButton(groupBox_3);
        kcfg_Color9->setObjectName("kcfg_Color9");

        gridLayout2->addWidget(kcfg_Color9, 4, 1, 1, 1);

        textLabel3_6 = new QLabel(groupBox_3);
        textLabel3_6->setObjectName("textLabel3_6");
        textLabel3_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(textLabel3_6, 4, 0, 1, 1);


        hboxLayout->addLayout(gridLayout2);


        vboxLayout->addWidget(groupBox_3);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);

#if QT_CONFIG(shortcut)
        textLabel1->setBuddy(kcfg_AxesColor);
        textLabel2->setBuddy(kcfg_GridColor);
        textLabel3->setBuddy(kcfg_Color1);
        textLabel3_13->setBuddy(kcfg_Color3);
        textLabel3_2->setBuddy(kcfg_Color2);
        textLabel3_12->setBuddy(kcfg_Color4);
        textLabel3_11->setBuddy(kcfg_Color5);
        textLabel3_9->setBuddy(kcfg_Color7);
        textLabel3_8->setBuddy(kcfg_Color8);
        textLabel3_10->setBuddy(kcfg_Color6);
        textLabel3_7->setBuddy(kcfg_Color9);
        textLabel3_6->setBuddy(kcfg_Color0);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_AxesColor, kcfg_GridColor);
        QWidget::setTabOrder(kcfg_GridColor, kcfg_Color0);
        QWidget::setTabOrder(kcfg_Color0, kcfg_Color1);
        QWidget::setTabOrder(kcfg_Color1, kcfg_Color2);
        QWidget::setTabOrder(kcfg_Color2, kcfg_Color3);
        QWidget::setTabOrder(kcfg_Color3, kcfg_Color4);
        QWidget::setTabOrder(kcfg_Color4, kcfg_Color5);
        QWidget::setTabOrder(kcfg_Color5, kcfg_Color6);
        QWidget::setTabOrder(kcfg_Color6, kcfg_Color7);
        QWidget::setTabOrder(kcfg_Color7, kcfg_Color8);
        QWidget::setTabOrder(kcfg_Color8, kcfg_Color9);

        retranslateUi(SettingsPageColor);

        QMetaObject::connectSlotsByName(SettingsPageColor);
    } // setupUi

    void retranslateUi(QWidget *SettingsPageColor)
    {
        groupBox_2->setTitle(tr2i18n("&Coords", nullptr));
        label->setText(tr2i18n("Background color:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_backgroundcolor->setToolTip(tr2i18n("Color for the plot area behind the grid.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_backgroundcolor->setWhatsThis(tr2i18n("Click on the button the choose the color of the background. This option has no effect on printing nor export.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_backgroundcolor->setText(QString());
        textLabel1->setText(tr2i18n("&Axes:", nullptr));
        textLabel2->setText(tr2i18n("&Grid:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AxesColor->setToolTip(tr2i18n("Select color for the axes.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_AxesColor->setWhatsThis(tr2i18n("Specify the color of the axes. The change will appear as soon as you press the OK button.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AxesColor->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_GridColor->setToolTip(tr2i18n("Select color for the grid.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_GridColor->setWhatsThis(tr2i18n("Specify the color of the grid. The change will appear as soon as you press the OK button.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_GridColor->setText(QString());
        groupBox_3->setTitle(tr2i18n("&Default Function Colors", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Color1->setToolTip(tr2i18n("The default color for function number 2.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color1->setWhatsThis(tr2i18n("The default color for function number 2. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color1->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_Color4->setToolTip(tr2i18n("The default color for function number 5.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color4->setWhatsThis(tr2i18n("The default color for function number 5. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color4->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_Color0->setToolTip(tr2i18n("The default color for function number 1.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color0->setWhatsThis(tr2i18n("The default color for function number 1. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color0->setText(QString());
        textLabel3->setText(tr2i18n("Function &1:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Color2->setToolTip(tr2i18n("The default color for function number 3.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color2->setWhatsThis(tr2i18n("The default color for function number 3. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color2->setText(QString());
        textLabel3_13->setText(tr2i18n("Function &3:", nullptr));
        textLabel3_2->setText(tr2i18n("Function &2:", nullptr));
        textLabel3_12->setText(tr2i18n("Function &4:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Color3->setToolTip(tr2i18n("The default color for function number 4.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color3->setWhatsThis(tr2i18n("The default color for function number 4. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color3->setText(QString());
        textLabel3_11->setText(tr2i18n("Function &5:", nullptr));
        textLabel3_9->setText(tr2i18n("Function &7:", nullptr));
        textLabel3_8->setText(tr2i18n("Function &8:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Color8->setToolTip(tr2i18n("The default color for function number 9.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color8->setWhatsThis(tr2i18n("The default color for function number 9. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color8->setText(QString());
        textLabel3_10->setText(tr2i18n("Function &6:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Color6->setToolTip(tr2i18n("The default color for function number 7.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color6->setWhatsThis(tr2i18n("The default color for function number 7. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color6->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_Color7->setToolTip(tr2i18n("The default color for function number 8.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color7->setWhatsThis(tr2i18n("The default color for function number 8. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color7->setText(QString());
#if QT_CONFIG(tooltip)
        kcfg_Color5->setToolTip(tr2i18n("The default color for function number 6.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color5->setWhatsThis(tr2i18n("The default color for function number 6. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color5->setText(QString());
        textLabel3_7->setText(tr2i18n("Function &9:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Color9->setToolTip(tr2i18n("The default color for function number 10.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_Color9->setWhatsThis(tr2i18n("The default color for function number 10. Please note that this color setting only affects empty functions, so if you have defined a function at number 1 and you change color for that number here, the setting will be shown next time you define a new function at number 1.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_Color9->setText(QString());
        textLabel3_6->setText(tr2i18n("Function 1&0:", nullptr));
        (void)SettingsPageColor;
    } // retranslateUi

};

namespace Ui {
    class SettingsPageColor: public Ui_SettingsPageColor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSPAGECOLOR_H

