/********************************************************************************
** Form generated from reading UI file 'settingspagefonts.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSPAGEFONTS_H
#define UI_SETTINGSPAGEFONTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SettingsPageFonts
{
public:
    QFormLayout *formLayout;
    QLabel *textLabel10;
    KFontRequester *kcfg_AxesFont;
    QLabel *textLabel10_3;
    KFontRequester *kcfg_LabelFont;
    QLabel *textLabel10_4;
    KFontRequester *kcfg_HeaderTableFont;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *SettingsPageFonts)
    {
        if (SettingsPageFonts->objectName().isEmpty())
            SettingsPageFonts->setObjectName("SettingsPageFonts");
        SettingsPageFonts->resize(353, 229);
        formLayout = new QFormLayout(SettingsPageFonts);
        formLayout->setObjectName("formLayout");
        textLabel10 = new QLabel(SettingsPageFonts);
        textLabel10->setObjectName("textLabel10");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel10->sizePolicy().hasHeightForWidth());
        textLabel10->setSizePolicy(sizePolicy);
        textLabel10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, textLabel10);

        kcfg_AxesFont = new KFontRequester(SettingsPageFonts);
        kcfg_AxesFont->setObjectName("kcfg_AxesFont");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_AxesFont);

        textLabel10_3 = new QLabel(SettingsPageFonts);
        textLabel10_3->setObjectName("textLabel10_3");
        sizePolicy.setHeightForWidth(textLabel10_3->sizePolicy().hasHeightForWidth());
        textLabel10_3->setSizePolicy(sizePolicy);
        textLabel10_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabel10_3);

        kcfg_LabelFont = new KFontRequester(SettingsPageFonts);
        kcfg_LabelFont->setObjectName("kcfg_LabelFont");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_LabelFont);

        textLabel10_4 = new QLabel(SettingsPageFonts);
        textLabel10_4->setObjectName("textLabel10_4");
        sizePolicy.setHeightForWidth(textLabel10_4->sizePolicy().hasHeightForWidth());
        textLabel10_4->setSizePolicy(sizePolicy);
        textLabel10_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, textLabel10_4);

        kcfg_HeaderTableFont = new KFontRequester(SettingsPageFonts);
        kcfg_HeaderTableFont->setObjectName("kcfg_HeaderTableFont");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_HeaderTableFont);

        spacerItem = new QSpacerItem(20, 110, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(3, QFormLayout::ItemRole::FieldRole, spacerItem);

#if QT_CONFIG(shortcut)
        textLabel10->setBuddy(kcfg_HeaderTableFont);
        textLabel10_3->setBuddy(kcfg_LabelFont);
        textLabel10_4->setBuddy(kcfg_AxesFont);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SettingsPageFonts);

        QMetaObject::connectSlotsByName(SettingsPageFonts);
    } // setupUi

    void retranslateUi(QWidget *SettingsPageFonts)
    {
        textLabel10->setText(tr2i18n("Axes labels:", nullptr));
        textLabel10_3->setText(tr2i18n("Diagram labels:", nullptr));
        textLabel10_4->setText(tr2i18n("Header table:", nullptr));
        (void)SettingsPageFonts;
    } // retranslateUi

};

namespace Ui {
    class SettingsPageFonts: public Ui_SettingsPageFonts {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGSPAGEFONTS_H

