/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmplot.KmPlot.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kmplotadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KmPlotAdaptor
 */

KmPlotAdaptor::KmPlotAdaptor(KmPlot *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KmPlotAdaptor::~KmPlotAdaptor()
{
    // destructor
}

void KmPlotAdaptor::fileOpen(const QString &url)
{
    // handle method call org.kde.kmplot.KmPlot.fileOpen
    parent()->fileOpen(url);
}

void KmPlotAdaptor::openFileInNewWindow(const QString &url)
{
    // handle method call org.kde.kmplot.KmPlot.openFileInNewWindow
    parent()->openFileInNewWindow(url);
}

void KmPlotAdaptor::setDrawProgress(double progress)
{
    // handle method call org.kde.kmplot.KmPlot.setDrawProgress
    parent()->setDrawProgress(progress);
}

void KmPlotAdaptor::setStatusBarText(const QString &text, int id)
{
    // handle method call org.kde.kmplot.KmPlot.setStatusBarText
    parent()->setStatusBarText(text, id);
}


#include "moc_kmplotadaptor.cpp"
